@@ -31,6 +31,7 @@
 #include "weechat.h"
 #include "core-upgrade.h"
 #include "core-dir.h"
+#include "core-hashtable.h"
 #include "core-hook.h"
 #include "core-infolist.h"
 #include "core-secure-buffer.h"
@@ -437,15 +438,17 @@ upgrade_weechat_read_buffer (struct t_infolist *infolist)
     {
         /* use WeeChat main buffer */
         upgrade_current_buffer = gui_buffers;
+        hashtable_remove (gui_buffer_by_id, &(upgrade_current_buffer->id));
         upgrade_current_buffer->id = id;
+        hashtable_set (gui_buffer_by_id, &id, upgrade_current_buffer);
     }
     else
     {
-        /* create buffer it it's not main buffer */
+        /* create buffer if it's not main buffer */
         upgrade_current_buffer = gui_buffer_new_props_with_id (
             id,
             NULL,  /* plugin */
-            infolist_string (infolist, "name"),
+            name,
             NULL,  /* properties */
             NULL, NULL, NULL,  /* input callback */
             NULL, NULL, NULL);  /* close callback */
@@ -477,7 +480,7 @@ upgrade_weechat_read_buffer (struct t_infolist *infolist)
     /* short name */
     free (ptr_buffer->short_name);
     str = infolist_string (infolist, "short_name");
-    ptr_buffer->short_name = (str) ? strdup (str) : NULL;
+    ptr_buffer->short_name = strdup ((str) ? str : name);
 
     /* buffer type */
     ptr_buffer->type = infolist_integer (infolist, "type");
