@@ -56,28 +56,28 @@
 #endif
 
 #include "weechat.h"
-#include "wee-command.h"
-#include "wee-completion.h"
-#include "wee-config.h"
-#include "wee-debug.h"
-#include "wee-dir.h"
-#include "wee-doc.h"
-#include "wee-eval.h"
-#include "wee-hdata.h"
-#include "wee-hook.h"
-#include "wee-list.h"
-#include "wee-log.h"
-#include "wee-network.h"
-#include "wee-proxy.h"
-#include "wee-secure.h"
-#include "wee-secure-config.h"
-#include "wee-signal.h"
-#include "wee-string.h"
-#include "wee-upgrade.h"
-#include "wee-url.h"
-#include "wee-utf8.h"
-#include "wee-util.h"
-#include "wee-version.h"
+#include "core-command.h"
+#include "core-completion.h"
+#include "core-config.h"
+#include "core-debug.h"
+#include "core-dir.h"
+#include "core-doc.h"
+#include "core-eval.h"
+#include "core-hdata.h"
+#include "core-hook.h"
+#include "core-list.h"
+#include "core-log.h"
+#include "core-network.h"
+#include "core-proxy.h"
+#include "core-secure.h"
+#include "core-secure-config.h"
+#include "core-signal.h"
+#include "core-string.h"
+#include "core-upgrade.h"
+#include "core-url.h"
+#include "core-utf8.h"
+#include "core-util.h"
+#include "core-version.h"
 #include "../gui/gui-chat.h"
 #include "../gui/gui-color.h"
 #include "../gui/gui-completion.h"
@@ -115,6 +115,7 @@ int weechat_home_temp = 0;             /* 1 if using a temporary home       */
 int weechat_home_delete_on_exit = 0;   /* 1 if home is deleted on exit      */
 char *weechat_config_dir = NULL;       /* config directory                  */
 char *weechat_data_dir = NULL;         /* data directory                    */
+char *weechat_state_dir = NULL;        /* state directory                   */
 char *weechat_cache_dir = NULL;        /* cache directory                   */
 char *weechat_runtime_dir = NULL;      /* runtime directory                 */
 int weechat_locale_ok = 0;             /* is locale OK?                     */
@@ -178,14 +179,15 @@ weechat_display_usage ()
           "  -c, --colors             display default colors in terminal "
           "and exit\n"
           "  -d, --dir <path>         force a single WeeChat home directory\n"
-          "                           or 4 different directories separated "
-          "by colons (in this order: config, data, cache, runtime)\n"
+          "                           or 5 different directories separated "
+          "by colons (in this order: config, data, state, cache, runtime)\n"
           "                           (environment variable WEECHAT_HOME is "
           "read if this option is not given)\n"
           "  -t, --temp-dir           create a temporary WeeChat home "
           "directory and delete it on exit\n"
           "                           (incompatible with option \"-d\")\n"
           "  -h, --help               display this help and exit\n"
+          "  -i, --build-info         display build information and exit\n"
           "  -l, --license            display WeeChat license and exit\n"
           "  -p, --no-plugin          don't load any plugin at startup\n"
           "  -P, --plugins <plugins>  load only these plugins at startup\n"
@@ -257,6 +259,7 @@ weechat_parse_args (int argc, char *argv[])
         { "dir",         required_argument, NULL, 'd'               },
         { "temp-dir",    no_argument,       NULL, 't'               },
         { "help",        no_argument,       NULL, 'h'               },
+        { "build-info",  no_argument,       NULL, 'i'               },
         { "license",     no_argument,       NULL, 'l'               },
         { "no-plugin",   no_argument,       NULL, 'p'               },
         { "plugins",     required_argument, NULL, 'P'               },
@@ -286,7 +289,7 @@ weechat_parse_args (int argc, char *argv[])
     opterr = 0;
 
     while ((opt = getopt_long (argc, argv,
-                               ":acd:thlpP:r:sv",
+                               ":acd:thilpP:r:sv",
                                long_options, NULL)) != -1)
     {
         switch (opt)
@@ -300,8 +303,7 @@ weechat_parse_args (int argc, char *argv[])
                 break;
             case 'd': /* -d / --dir */
                 weechat_home_temp = 0;
-                if (weechat_home_force)
-                    free (weechat_home_force);
+                free (weechat_home_force);
                 weechat_home_force = strdup (optarg);
                 break;
             case 't': /* -t / --temp-dir */
@@ -316,6 +318,10 @@ weechat_parse_args (int argc, char *argv[])
                 weechat_display_usage ();
                 weechat_shutdown (EXIT_SUCCESS, 0);
                 break;
+            case 'i': /* -i / --build-info */
+                debug_build_info ();
+                weechat_shutdown (EXIT_SUCCESS, 0);
+                break;
             case 'l': /* -l / --license */
                 weechat_display_copyright ();
                 string_fprintf (stdout, "\n");
@@ -323,13 +329,11 @@ weechat_parse_args (int argc, char *argv[])
                 weechat_shutdown (EXIT_SUCCESS, 0);
                 break;
             case 'p': /* -p / --no-plugin */
-                if (weechat_force_plugin_autoload)
-                    free (weechat_force_plugin_autoload);
+                free (weechat_force_plugin_autoload);
                 weechat_force_plugin_autoload = strdup ("!*");
                 break;
             case 'P': /* -P / --plugins */
-                if (weechat_force_plugin_autoload)
-                    free (weechat_force_plugin_autoload);
+                free (weechat_force_plugin_autoload);
                 weechat_force_plugin_autoload = strdup (optarg);
                 break;
             case 'r': /* -r / --run-command */
@@ -575,26 +579,17 @@ weechat_shutdown (int return_code, int crash)
         dir_remove_home_dirs ();
     }
 
-    if (weechat_argv0)
-        free (weechat_argv0);
-    if (weechat_home_force)
-        free (weechat_home_force);
-    if (weechat_config_dir)
-        free (weechat_config_dir);
-    if (weechat_data_dir)
-        free (weechat_data_dir);
-    if (weechat_cache_dir)
-        free (weechat_cache_dir);
-    if (weechat_runtime_dir)
-        free (weechat_runtime_dir);
-    if (weechat_local_charset)
-        free (weechat_local_charset);
-    if (weechat_force_plugin_autoload)
-        free (weechat_force_plugin_autoload);
-    if (weechat_startup_commands)
-        weelist_free (weechat_startup_commands);
-    if (weechat_doc_gen_path)
-        free (weechat_doc_gen_path);
+    free (weechat_argv0);
+    free (weechat_home_force);
+    free (weechat_config_dir);
+    free (weechat_data_dir);
+    free (weechat_state_dir);
+    free (weechat_cache_dir);
+    free (weechat_runtime_dir);
+    free (weechat_local_charset);
+    free (weechat_force_plugin_autoload);
+    weelist_free (weechat_startup_commands);
+    free (weechat_doc_gen_path);
 
     if (crash)
         abort ();
@@ -612,11 +607,11 @@ void
 weechat_init_gettext ()
 {
     weechat_locale_ok = (setlocale (LC_ALL, "") != NULL);   /* init gettext */
-#ifdef ENABLE_NLS
+#if ENABLE_NLS == 1
     bindtextdomain (PACKAGE, LOCALEDIR);
     bind_textdomain_codeset (PACKAGE, "UTF-8");
     textdomain (PACKAGE);
-#endif /* ENABLE_NLS */
+#endif /* ENABLE_NLS == 1 */
 
 #ifdef HAVE_LANGINFO_CODESET
     weechat_local_charset = strdup (nl_langinfo (CODESET));
