@@ -1,7 +1,7 @@
 /*
  * gui-curses-bar-window.c - bar window functions for Curses GUI
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -28,10 +28,10 @@
 #include <limits.h>
 
 #include "../../core/weechat.h"
-#include "../../core/wee-config.h"
-#include "../../core/wee-log.h"
-#include "../../core/wee-string.h"
-#include "../../core/wee-utf8.h"
+#include "../../core/core-config.h"
+#include "../../core/core-log.h"
+#include "../../core/core-string.h"
+#include "../../core/core-utf8.h"
 #include "../../plugins/plugin.h"
 #include "../gui-bar.h"
 #include "../gui-bar-item.h"
@@ -397,8 +397,7 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                                      (output) ? output : utf_char2);
                             if (reverse_video)
                                 wattroff (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar, A_REVERSE);
-                            if (output)
-                                free (output);
+                            free (output);
 
                             if (gui_window_current_emphasis)
                             {
@@ -878,8 +877,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                 }
             }
         }
-        if (items)
-            string_free_split (items);
+        string_free_split (items);
         free (content);
     }
     else
@@ -963,6 +961,6 @@ void
 gui_bar_window_objects_print_log (struct t_gui_bar_window *bar_window)
 {
     log_printf ("    bar window specific objects for Curses:");
-    log_printf ("      win_bar. . . . . . . : 0x%lx", GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar);
-    log_printf ("      win_separator. . . . : 0x%lx", GUI_BAR_WINDOW_OBJECTS(bar_window)->win_separator);
+    log_printf ("      win_bar. . . . . . . : %p", GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar);
+    log_printf ("      win_separator. . . . : %p", GUI_BAR_WINDOW_OBJECTS(bar_window)->win_separator);
 }
