@@ -29,13 +29,13 @@
 #include <time.h>
 
 #include "../../core/weechat.h"
-#include "../../core/wee-config.h"
-#include "../../core/wee-eval.h"
-#include "../../core/wee-hashtable.h"
-#include "../../core/wee-hook.h"
-#include "../../core/wee-string.h"
-#include "../../core/wee-utf8.h"
-#include "../../core/wee-util.h"
+#include "../../core/core-config.h"
+#include "../../core/core-eval.h"
+#include "../../core/core-hashtable.h"
+#include "../../core/core-hook.h"
+#include "../../core/core-string.h"
+#include "../../core/core-utf8.h"
+#include "../../core/core-util.h"
 #include "../../plugins/plugin.h"
 #include "../gui-buffer.h"
 #include "../gui-chat.h"
@@ -359,7 +359,6 @@ gui_chat_string_next_char (struct t_gui_window *window, struct t_gui_line *line,
                 break;
             default:
                 return (char *)string;
-                break;
         }
     }
 
@@ -459,8 +458,7 @@ gui_chat_display_word_raw (struct t_gui_window *window, struct t_gui_line *line,
                                 wattroff (GUI_WINDOW_OBJECTS(window)->win_chat,
                                           A_REVERSE);
                             }
-                            if (output)
-                                free (output);
+                            free (output);
 
                             if (gui_window_current_emphasis)
                             {
@@ -764,8 +762,7 @@ gui_chat_display_day_changed (struct t_gui_window *window,
                                0, simulate, 0, 0);
     window->win_chat_cursor_x = window->win_chat_width;
 
-    if (message_with_color)
-        free (message_with_color);
+    free (message_with_color);
 }
 
 /*
@@ -805,14 +802,15 @@ gui_chat_display_time_to_prefix (struct t_gui_window *window,
                                  int num_lines, int count,
                                  int pre_lines_displayed,
                                  int *lines_displayed,
-                                 int simulate)
+                                 int simulate,
+                                 int nick_offline)
 {
     char str_space[] = " ";
     char *prefix_no_color, *prefix_highlighted, *ptr_prefix, *ptr_prefix2;
     char *ptr_prefix_color;
     const char *short_name, *str_color, *ptr_nick_prefix, *ptr_nick_suffix;
     int i, length, length_allowed, num_spaces, prefix_length, extra_spaces;
-    int chars_displayed, nick_offline, prefix_is_nick, length_nick_prefix_suffix;
+    int chars_displayed, prefix_is_nick, length_nick_prefix_suffix;
     int chars_to_display;
     struct t_gui_lines *mixed_lines;
 
@@ -908,7 +906,7 @@ gui_chat_display_time_to_prefix (struct t_gui_window *window,
         else
             length_allowed = mixed_lines->buffer_max_length;
 
-        short_name = gui_buffer_get_short_name (line->data->buffer);
+        short_name = line->data->buffer->short_name;
         length = gui_chat_strlen_screen (short_name);
         num_spaces = length_allowed - length;
 
@@ -1151,11 +1149,9 @@ gui_chat_display_time_to_prefix (struct t_gui_window *window,
                                    simulate, 0, 0);
         }
 
-        nick_offline = CONFIG_BOOLEAN(config_look_color_nick_offline)
-            && gui_line_has_offline_nick (line);
-
         prefix_highlighted = NULL;
-        if (line->data->highlight)
+        if (line->data->highlight
+            && CONFIG_BOOLEAN(config_look_highlight_prefix))
         {
             prefix_no_color = gui_color_decode (ptr_prefix, NULL);
             if (prefix_no_color)
@@ -1241,8 +1237,7 @@ gui_chat_display_time_to_prefix (struct t_gui_window *window,
         if (window->win_chat_cursor_y < window->coords_size)
             window->coords[window->win_chat_cursor_y].prefix_x2 = window->win_chat_cursor_x - 1;
 
-        if (prefix_highlighted)
-            free (prefix_highlighted);
+        free (prefix_highlighted);
 
         if (!simulate)
         {
@@ -1372,8 +1367,7 @@ gui_chat_display_time_to_prefix (struct t_gui_window *window,
                                    simulate, 0, 0);
         }
     }
-    if (ptr_prefix)
-        free (ptr_prefix);
+    free (ptr_prefix);
 }
 
 /*
@@ -1395,7 +1389,8 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
     int read_marker_x, read_marker_y;
     int word_start_offset, word_end_offset;
     int word_length_with_spaces, word_length;
-    char *message_with_tags, *message_with_search;
+    int nick_offline, nick_offline_action, nick_offline_prefix;
+    char *message_nick_offline, *message_with_tags, *message_with_search;
     const char *ptr_data, *ptr_end_offset, *ptr_style, *next_char;
     struct t_gui_line *ptr_prev_line, *ptr_next_line;
     struct tm local_time, local_time2;
@@ -1425,6 +1420,12 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
         gui_window_current_emphasis = 0;
     }
 
+    nick_offline = CONFIG_BOOLEAN(config_look_color_nick_offline)
+        && gui_line_has_offline_nick (line);
+    nick_offline_action = nick_offline && gui_line_is_action (line);
+    nick_offline_prefix = nick_offline
+        && (nick_offline_action || gui_line_search_tag_starting_with (line, "prefix_nick"));
+
     pre_lines_displayed = 0;
     lines_displayed = 0;
 
@@ -1471,7 +1472,7 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
     /* display time and prefix */
     gui_chat_display_time_to_prefix (window, line, num_lines, count,
                                      pre_lines_displayed, &lines_displayed,
-                                     simulate);
+                                     simulate, nick_offline_prefix);
     if (!simulate && !gui_chat_display_tags)
     {
         if (window->win_chat_cursor_y < window->coords_size)
@@ -1499,19 +1500,23 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
 
     /* display message */
     ptr_data = NULL;
+    message_nick_offline = NULL;
     message_with_tags = NULL;
     message_with_search = NULL;
 
     if (line->data->message && line->data->message[0])
     {
+        message_nick_offline = (nick_offline_action) ?
+            gui_line_build_string_message_nick_offline (line->data->message) : NULL;
+        ptr_data = (message_nick_offline) ?
+            message_nick_offline : line->data->message;
         message_with_tags = (gui_chat_display_tags) ?
-            gui_line_build_string_message_tags (line->data->message,
+            gui_line_build_string_message_tags (ptr_data,
                                                 line->data->tags_count,
                                                 line->data->tags_array,
                                                 1) : NULL;
-        ptr_data = (message_with_tags) ?
-            message_with_tags : line->data->message;
-        message_with_search = NULL;
+        if (message_with_tags)
+            ptr_data = message_with_tags;
         if ((window->buffer->text_search == GUI_BUFFER_SEARCH_LINES)
             && (window->buffer->text_search_where & GUI_BUFFER_SEARCH_IN_MESSAGE)
             && (!window->buffer->text_search_regex
@@ -1642,10 +1647,9 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
                                    &lines_displayed, simulate);
     }
 
-    if (message_with_tags)
-        free (message_with_tags);
-    if (message_with_search)
-        free (message_with_search);
+    free (message_nick_offline);
+    free (message_with_tags);
+    free (message_with_search);
 
     /* display message if day has changed after this line */
     if ((line->data->date != 0)
@@ -1797,10 +1801,8 @@ gui_chat_display_line_y (struct t_gui_window *window, struct t_gui_line *line,
         gui_window_clrtoeol (GUI_WINDOW_OBJECTS(window)->win_chat);
     }
 
-    if (message_with_tags)
-        free (message_with_tags);
-    if (message_with_search)
-        free (message_with_search);
+    free (message_with_tags);
+    free (message_with_search);
 }
 
 /*
@@ -2151,10 +2153,8 @@ gui_chat_get_bare_line (struct t_gui_line *line)
     }
 
 end:
-    if (prefix)
-        free (prefix);
-    if (message)
-        free (message);
+    free (prefix);
+    free (message);
 
     return str_line;
 }
