@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,9 +20,8 @@
 #ifndef WEECHAT_GUI_CURSES_MOUSE_H
 #define WEECHAT_GUI_CURSES_MOUSE_H
 
-#define MOUSE_CODE_BUTTON(code) ((code >= 32) && (code < 64))
-#define MOUSE_CODE_MOTION(code) ((code >= 64) && (code < 96))
-#define MOUSE_CODE_END(code)    ((code == '#') || (code == '3')         \
-                                 || (code == '+') || (code == ';'))
+#define MOUSE_CODE_UTF8_MOTION(code) ((code >= 64) && (code < 96))
+#define MOUSE_CODE_UTF8_END(code)    ((code == '#') || (code == '3')    \
+                                      || (code == '+') || (code == ';'))
 
 #endif /* WEECHAT_GUI_CURSES_MOUSE_H */
