@@ -1,7 +1,7 @@
 /*
  * gui-bar-item-custom.c - custom bar item functions (used by all GUI)
  *
- * Copyright (C) 2022-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2022-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -28,11 +28,11 @@
 #include <string.h>
 
 #include "../core/weechat.h"
-#include "../core/wee-config.h"
-#include "../core/wee-config-file.h"
-#include "../core/wee-eval.h"
-#include "../core/wee-hashtable.h"
-#include "../core/wee-string.h"
+#include "../core/core-config.h"
+#include "../core/core-config-file.h"
+#include "../core/core-eval.h"
+#include "../core/core-hashtable.h"
+#include "../core/core-string.h"
 #include "../plugins/plugin.h"
 #include "gui-bar-item-custom.h"
 #include "gui-bar-item.h"
@@ -333,10 +333,8 @@ gui_bar_item_custom_callback (const void *pointer,
         pointers, NULL, NULL);
 
 end:
-    if (pointers)
-        hashtable_free (pointers);
-    if (options)
-        hashtable_free (options);
+    hashtable_free (pointers);
+    hashtable_free (options);
 
     return result;
 }
@@ -376,8 +374,7 @@ gui_bar_item_custom_alloc (const char *name)
 void
 gui_bar_item_custom_create_bar_item (struct t_gui_bar_item_custom *item)
 {
-    if (item->bar_item)
-        gui_bar_item_free (item->bar_item);
+    gui_bar_item_free (item->bar_item);
     item->bar_item = gui_bar_item_new (
         NULL,
         item->name,
@@ -482,10 +479,8 @@ error:
     }
     else
     {
-        if (option_conditions)
-            config_file_option_free (option_conditions, 0);
-        if (option_content)
-            config_file_option_free (option_content, 0);
+        config_file_option_free (option_conditions, 0);
+        config_file_option_free (option_content, 0);
     }
     return NULL;
 }
@@ -611,12 +606,10 @@ gui_bar_item_custom_free_data (struct t_gui_bar_item_custom *item)
 {
     int i;
 
-    if (item->name)
-        free (item->name);
+    free (item->name);
     for (i = 0; i < GUI_BAR_ITEM_CUSTOM_NUM_OPTIONS; i++)
     {
-        if (item->options[i])
-            config_file_option_free (item->options[i], 1);
+        config_file_option_free (item->options[i], 1);
     }
 }
 
@@ -654,8 +647,7 @@ gui_bar_item_custom_free (struct t_gui_bar_item_custom *item)
 
     gui_bar_item_update (name);
 
-    if (name)
-        free (name);
+    free (name);
 }
 
 /*
