@@ -1,7 +1,7 @@
 /*
  * buflist-config.c - buflist configuration options (file buflist.conf)
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -328,8 +328,7 @@ buflist_config_change_sort (const void *pointer, void *data,
             0,
             &buflist_config_sort_fields_count[i]);
 
-        if (sort)
-            free (sort);
+        free (sort);
     }
 
     weechat_hashtable_free (hashtable_pointers);
@@ -446,18 +445,15 @@ buflist_config_change_format (const void *pointer, void *data,
     (void) data;
     (void) option;
 
-    if (buflist_config_format_buffer_eval)
-        free (buflist_config_format_buffer_eval);
+    free (buflist_config_format_buffer_eval);
     buflist_config_format_buffer_eval = buflist_config_add_eval_for_formats (
         weechat_config_string (buflist_config_format_buffer));
 
-    if (buflist_config_format_buffer_current_eval)
-        free (buflist_config_format_buffer_current_eval);
+    free (buflist_config_format_buffer_current_eval);
     buflist_config_format_buffer_current_eval = buflist_config_add_eval_for_formats (
         weechat_config_string (buflist_config_format_buffer_current));
 
-    if (buflist_config_format_hotlist_eval)
-        free (buflist_config_format_hotlist_eval);
+    free (buflist_config_format_hotlist_eval);
     buflist_config_format_hotlist_eval = buflist_config_add_eval_for_formats (
         weechat_config_string (buflist_config_format_hotlist));
 
@@ -498,7 +494,7 @@ buflist_config_init ()
             N_("add newline between the buffers displayed, so each buffer is "
                "displayed on a separate line (recommended); if disabled, "
                "newlines must be manually added in the formats with \"${\\n}\", "
-               "and the mouse actions are not possible any more"),
+               "and the mouse actions are not possible anymore"),
             NULL, 0, 0, "on", NULL, 0,
             NULL, NULL, NULL,
             &buflist_config_change_buflist, NULL, NULL,
@@ -534,7 +530,7 @@ buflist_config_init ()
             "enabled", "boolean",
             N_("enable buflist; it is recommended to use this option instead of "
                "just hiding the bar because it also removes some internal hooks "
-               "that are not needed any more when the bar is hidden; you can "
+               "that are not needed anymore when the bar is hidden; you can "
                "also use the command \"/buflist toggle\" or use the default key "
                "alt+shift+b"),
             NULL, 0, 0, "on", NULL, 0,
@@ -606,10 +602,10 @@ buflist_config_init ()
                "IRC server (\"irc_server.var\") or a hdata variable of "
                "IRC channel (\"irc_channel.var\"); "
                "char \"-\" can be used before field to reverse order, "
-               "char \"~\" can be used to do a case insensitive comparison; "
-               "examples: \"-~short_name\" for case insensitive and reverse "
+               "char \"~\" can be used to do a case-insensitive comparison; "
+               "examples: \"-~short_name\" for case-insensitive and reverse "
                "sort on buffer short name, "
-               "\"-hotlist.priority,hotlist.creation_time.tv_sec,number,-active\" "
+               "\"-hotlist.priority,hotlist.time,hotlist.time_usec,number,-active\" "
                "for sort like the hotlist then by buffer number for buffers "
                "without activity "
                "(note: the content is evaluated, before being split into "
@@ -844,6 +840,7 @@ buflist_config_free ()
     int i;
 
     weechat_config_free (buflist_config_file);
+    buflist_config_file = NULL;
 
     if (buflist_config_signals_refresh)
         buflist_config_free_signals_refresh ();
@@ -858,10 +855,12 @@ buflist_config_free ()
         }
     }
 
-    if (buflist_config_format_buffer_eval)
-        free (buflist_config_format_buffer_eval);
-    if (buflist_config_format_buffer_current_eval)
-        free (buflist_config_format_buffer_current_eval);
-    if (buflist_config_format_hotlist_eval)
-        free (buflist_config_format_hotlist_eval);
+    free (buflist_config_format_buffer_eval);
+    buflist_config_format_buffer_eval = NULL;
+
+    free (buflist_config_format_buffer_current_eval);
+    buflist_config_format_buffer_current_eval = NULL;
+
+    free (buflist_config_format_hotlist_eval);
+    buflist_config_format_hotlist_eval = NULL;
 }
