@@ -333,7 +333,6 @@ buflist_hsignal_cb (const void *pointer, void *data, const char *signal,
     struct t_gui_buffer *ptr_buffer;
     char *error, str_command[1024];
     long number, number2;
-    unsigned long value;
     int rc, current_buffer_number;
 
     /* make C compiler happy */
@@ -353,10 +352,9 @@ buflist_hsignal_cb (const void *pointer, void *data, const char *signal,
         return WEECHAT_RC_OK;
     }
 
-    rc = sscanf (ptr_pointer, "%lx", &value);
+    rc = sscanf (ptr_pointer, "%p", &ptr_buffer);
     if ((rc == EOF) || (rc == 0))
         return WEECHAT_RC_OK;
-    ptr_buffer = (struct t_gui_buffer *)value;
 
     error = NULL;
     number = strtol (ptr_number, &error, 10);
