@@ -138,7 +138,7 @@ exec_command_list ()
 
 /*
  * Searches a running command by id, and displays an error if command is not
- * found or not running any more.
+ * found or not running anymore.
  *
  * Returns the command found, or NULL if not found or not running.
  */
@@ -162,8 +162,7 @@ exec_command_search_running_id (const char *id)
     if (!ptr_exec_cmd->hook)
     {
         weechat_printf (NULL,
-                        _("%s%s: command with id \"%s\" is not running any "
-                          "more"),
+                        _("%s%s: command with id \"%s\" is not running anymore"),
                         weechat_prefix ("error"), EXEC_PLUGIN_NAME, id);
         return NULL;
     }
@@ -827,7 +826,7 @@ exec_command_init ()
     weechat_hook_command (
         "exec",
         N_("execute external commands"),
-        /* TRANSLATORS: only text between angle brackets (eg: "<name>") must be translated */
+        /* TRANSLATORS: only text between angle brackets (eg: "<name>") may be translated */
         N_("-list"
            " || [-sh|-nosh] [-bg|-nobg] [-stdin|-nostdin] [-buffer <name>] "
            "[-l|-o|-oc|-n|-nf] [-oerr] [-cl|-nocl] [-sw|-nosw] [-ln|-noln] "
