@@ -1,7 +1,7 @@
 /*
  * fset-buffer.c - buffer for Fast Set plugin
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -1071,8 +1071,7 @@ fset_buffer_display_option_predefined_format (struct t_fset_option *fset_option)
         str_type,
         (str_value) ? str_value : "");
 
-    if (str_value)
-        free (str_value);
+    free (str_value);
 
     return fset_option->index;
 }
@@ -1598,8 +1597,7 @@ fset_buffer_open ()
         &fset_buffer_input_cb, NULL, NULL,
         &fset_buffer_close_cb, NULL, NULL);
 
-    if (buffer_props)
-        weechat_hashtable_free (buffer_props);
+    weechat_hashtable_free (buffer_props);
 
     if (!fset_buffer)
         return;
@@ -1654,9 +1652,21 @@ fset_buffer_init ()
 void
 fset_buffer_end ()
 {
-    weechat_hashtable_free (fset_buffer_hashtable_pointers);
-    fset_buffer_hashtable_pointers = NULL;
+    if (fset_buffer)
+    {
+        weechat_buffer_close (fset_buffer);
+        fset_buffer = NULL;
+    }
 
-    weechat_hashtable_free (fset_buffer_hashtable_extra_vars);
-    fset_buffer_hashtable_extra_vars = NULL;
+    if (fset_buffer_hashtable_pointers)
+    {
+        weechat_hashtable_free (fset_buffer_hashtable_pointers);
+        fset_buffer_hashtable_pointers = NULL;
+    }
+
+    if (fset_buffer_hashtable_extra_vars)
+    {
+        weechat_hashtable_free (fset_buffer_hashtable_extra_vars);
+        fset_buffer_hashtable_extra_vars = NULL;
+    }
 }
