@@ -1,7 +1,7 @@
 /*
  * fset-config.c - Fast Set configuration options (file fset.conf)
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -142,9 +142,7 @@ fset_config_change_auto_refresh_cb (const void *pointer, void *data,
     (void) data;
     (void) option;
 
-    if (fset_config_auto_refresh)
-        weechat_string_free_split (fset_config_auto_refresh);
-
+    weechat_string_free_split (fset_config_auto_refresh);
     fset_config_auto_refresh = weechat_string_split (
         weechat_config_string (fset_config_look_auto_refresh),
         ",",
@@ -206,9 +204,7 @@ fset_config_change_sort_cb (const void *pointer, void *data,
     (void) data;
     (void) option;
 
-    if (fset_config_sort_fields)
-        weechat_string_free_split (fset_config_sort_fields);
-
+    weechat_string_free_split (fset_config_sort_fields);
     fset_config_sort_fields = weechat_string_split (
         weechat_config_string (fset_config_look_sort),
         ",",
@@ -470,8 +466,8 @@ fset_config_init ()
             "sort", "string",
             N_("comma-separated list of fields to sort options (see /help fset "
                "for a list of fields); char \"-\" can be used before field to "
-               "reverse order, char \"~\" can be used to do a case insensitive "
-               "comparison; example: \"-~name\" for case insensitive and "
+               "reverse order, char \"~\" can be used to do a case-insensitive "
+               "comparison; example: \"-~name\" for case-insensitive and "
                "reverse sort on option name"),
             NULL, 0, 0, "~name", NULL, 0,
             NULL, NULL, NULL,
@@ -1186,6 +1182,7 @@ void
 fset_config_free ()
 {
     weechat_config_free (fset_config_file);
+    fset_config_file = NULL;
 
     if (fset_config_auto_refresh)
     {
