@@ -1,7 +1,7 @@
 /*
  * irc-batch.c - functions for managing batched events
  *
- * Copyright (C) 2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -80,7 +80,7 @@ irc_batch_generate_random_ref (char *string, int size)
     length_chars = strlen (chars);
     for (i = 0; i < size; i++)
     {
-        string[i] = chars[rand() % length_chars];
+        string[i] = chars[rand () % length_chars];
     }
     string[size] = '\0';
 }
@@ -181,18 +181,12 @@ irc_batch_add_message (struct t_irc_server *server, const char *reference,
 void
 irc_batch_free (struct t_irc_server *server, struct t_irc_batch *batch)
 {
-    if (batch->reference)
-        free (batch->reference);
-    if (batch->parent_ref)
-        free (batch->parent_ref);
-    if (batch->type)
-        free (batch->type);
-    if (batch->parameters)
-        free (batch->parameters);
-    if (batch->tags)
-        weechat_hashtable_free (batch->tags);
-    if (batch->messages)
-        weechat_string_dyn_free (batch->messages, 1);
+    free (batch->reference);
+    free (batch->parent_ref);
+    free (batch->type);
+    free (batch->parameters);
+    weechat_hashtable_free (batch->tags);
+    weechat_string_dyn_free (batch->messages, 1);
 
     /* remove batch from list */
     if (batch->prev_batch)
@@ -295,17 +289,14 @@ irc_batch_process_messages (struct t_irc_server *server,
 
                 free (message);
                 free (message2);
-                if (command)
-                    free (command);
-                if (channel)
-                    free (channel);
+                free (command);
+                free (channel);
             }
             weechat_string_free_split (list_messages);
         }
     }
 
-    if (new_messages)
-        free (new_messages);
+    free (new_messages);
 }
 
 /*
@@ -427,7 +418,7 @@ irc_batch_process_multiline (struct t_irc_server *server,
                 if (tags && tags[0])
                     irc_tag_parse (tags, hash_tags, NULL);
             }
-            if (*result[0])
+            if ((*result)[0])
             {
                 if (!hash_tags
                     || !weechat_hashtable_has_key (hash_tags,
@@ -455,23 +446,16 @@ irc_batch_process_multiline (struct t_irc_server *server,
             if (text)
                 weechat_string_dyn_concat (result, text, -1);
         }
-        if (tags)
-            free (tags);
-        if (host)
-            free (host);
-        if (command)
-            free (command);
-        if (channel)
-            free (channel);
-        if (text)
-            free (text);
+        free (tags);
+        free (host);
+        free (command);
+        free (channel);
+        free (text);
     }
 
 end:
-    if (hash_tags)
-        weechat_hashtable_free (hash_tags);
-    if (list_messages)
-        weechat_string_free_split (list_messages);
+    weechat_hashtable_free (hash_tags);
+    weechat_string_free_split (list_messages);
 
     return weechat_string_dyn_free (result, 0);
 }
@@ -514,8 +498,7 @@ irc_batch_modifier_cb (const void *pointer, void *data,
             result = irc_batch_process_multiline (ptr_server, string, items[2]);
         }
     }
-    if (items)
-        weechat_string_free_split (items);
+    weechat_string_free_split (items);
 
     return (result) ? result : strdup (string);
 }
@@ -565,22 +548,22 @@ irc_batch_print_log (struct t_irc_server *server)
          ptr_batch = ptr_batch->next_batch)
     {
         weechat_log_printf ("");
-        weechat_log_printf ("  => batch (addr:0x%lx):", ptr_batch);
-        weechat_log_printf ("       reference . . . . . : '%s'",  ptr_batch->reference);
-        weechat_log_printf ("       parent_ref. . . . . : '%s'",  ptr_batch->parent_ref);
-        weechat_log_printf ("       type. . . . . . . . : '%s'",  ptr_batch->type);
-        weechat_log_printf ("       parameters. . . . . : '%s'",  ptr_batch->parameters);
-        weechat_log_printf ("       tags. . . . . . . . : 0x%lx (hashtable: '%s')",
+        weechat_log_printf ("  => batch (addr:%p):", ptr_batch);
+        weechat_log_printf ("       reference . . . . . : '%s'", ptr_batch->reference);
+        weechat_log_printf ("       parent_ref. . . . . : '%s'", ptr_batch->parent_ref);
+        weechat_log_printf ("       type. . . . . . . . : '%s'", ptr_batch->type);
+        weechat_log_printf ("       parameters. . . . . : '%s'", ptr_batch->parameters);
+        weechat_log_printf ("       tags. . . . . . . . : %p (hashtable: '%s')",
                             ptr_batch->tags,
                             weechat_hashtable_get_string (ptr_batch->tags,
                                                           "keys_values"));
-        weechat_log_printf ("       start_time. . . . . : %lld",  (long long)ptr_batch->start_time);
-        weechat_log_printf ("       message . . . . . . : 0x%lx ('%s')",
+        weechat_log_printf ("       start_time. . . . . : %lld", (long long)ptr_batch->start_time);
+        weechat_log_printf ("       message . . . . . . : %p ('%s')",
                             ptr_batch->messages,
                             (ptr_batch->messages) ? *(ptr_batch->messages) : NULL);
-        weechat_log_printf ("       end_received. . . . : %d",    ptr_batch->end_received);
-        weechat_log_printf ("       messages_processed. : %d",    ptr_batch->messages_processed);
-        weechat_log_printf ("       prev_batch. . . . . : 0x%lx", ptr_batch->prev_batch);
-        weechat_log_printf ("       next_batch. . . . . : 0x%lx", ptr_batch->next_batch);
+        weechat_log_printf ("       end_received. . . . : %d", ptr_batch->end_received);
+        weechat_log_printf ("       messages_processed. : %d", ptr_batch->messages_processed);
+        weechat_log_printf ("       prev_batch. . . . . : %p", ptr_batch->prev_batch);
+        weechat_log_printf ("       next_batch. . . . . : %p", ptr_batch->next_batch);
     }
 }
