@@ -94,8 +94,7 @@ irc_ctcp_convert_legacy_format (const char *format)
                   "${%s}",
                   ctcp_legacy_vars[i]);
         str2 = weechat_string_replace (str, old_format, new_format);
-        if (str)
-            free (str);
+        free (str);
         str = str2;
     }
 
@@ -169,6 +168,45 @@ irc_ctcp_get_reply (struct t_irc_server *server, const char *ctcp)
     return irc_ctcp_get_default_reply (ctcp);
 }
 
+/*
+ * Extracts CTCP type and arguments from message, which format is:
+ *   \001TYPE arguments...\001
+ *
+ * Strings *type and *arguments are set with type and arguments parsed,
+ * both are set to NULL in case of error.
+ */
+
+void
+irc_ctcp_parse_type_arguments (const char *message,
+                               char **type, char **arguments)
+{
+    const char *pos_end, *pos_space;
+
+    if (!message || !type || !arguments)
+        return;
+
+    *type = NULL;
+    *arguments = NULL;
+
+    if (message[0] != '\001')
+        return;
+
+    pos_end = strrchr (message + 1, '\001');
+    if (!pos_end)
+        return;
+
+    pos_space = strchr (message + 1, ' ');
+
+    *type = weechat_strndup (
+        message + 1,
+        (pos_space) ? pos_space - message - 1 : pos_end - message - 1);
+    if (!*type)
+        return;
+
+    *arguments = (pos_space) ?
+        weechat_strndup (pos_space + 1, pos_end - pos_space - 1) : NULL;
+}
+
 /*
  * Displays CTCP requested by a nick.
  */
@@ -200,8 +238,8 @@ irc_ctcp_display_request (struct t_irc_protocol_ctxt *ctxt,
         IRC_COLOR_CHAT_CHANNEL,
         ctcp,
         IRC_COLOR_RESET,
-        (arguments) ? " " : "",
-        (arguments) ? arguments : "",
+        (arguments && arguments[0]) ? " " : "",
+        (arguments && arguments[0]) ? arguments : "",
         (reply && !reply[0]) ? _(" (blocked)") : "");
 }
 
@@ -225,7 +263,7 @@ irc_ctcp_display_reply_from_nick (struct t_irc_protocol_ctxt *ctxt,
 
     while (ptr_args && ptr_args[0])
     {
-        pos_end = strrchr (ptr_args + 1, '\01');
+        pos_end = strrchr (ptr_args + 1, '\001');
         if (pos_end)
             pos_end[0] = '\0';
 
@@ -289,7 +327,7 @@ irc_ctcp_display_reply_from_nick (struct t_irc_protocol_ctxt *ctxt,
                     ptr_args + 1,
                     IRC_COLOR_RESET,
                     " ",
-                    pos_args);
+                    IRC_COLOR_MSG(pos_args));
             }
         }
         else
@@ -319,18 +357,75 @@ irc_ctcp_display_reply_from_nick (struct t_irc_protocol_ctxt *ctxt,
 }
 
 /*
- * Displays CTCP replied to a nick.
+ * Displays CTCP reply to a nick (internal function).
+ */
+
+void
+irc_ctcp_display_reply_to_nick_internal (struct t_irc_protocol_ctxt *ctxt,
+                                         const char *target,
+                                         const char *type,
+                                         const char *args)
+{
+    weechat_printf_date_tags (
+        irc_msgbuffer_get_target_buffer (ctxt->server, target, NULL,
+                                         "ctcp", NULL),
+        0,
+        irc_protocol_tags (ctxt,
+                           "irc_ctcp,irc_ctcp_reply,self_msg,"
+                           "notify_none,no_highlight"),
+        _("%sCTCP reply to %s%s%s: %s%s%s%s%s"),
+        weechat_prefix ("network"),
+        irc_nick_color_for_msg (ctxt->server, 0, NULL, target),
+        target,
+        IRC_COLOR_RESET,
+        IRC_COLOR_CHAT_CHANNEL,
+        type,
+        (args && args[0]) ? IRC_COLOR_RESET : "",
+        (args && args[0]) ? " " : "",
+        (args && args[0]) ? IRC_COLOR_MSG(args) : "");
+}
+
+/*
+ * Displays CTCP reply to a nick.
+ */
+
+void
+irc_ctcp_display_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
+                                const char *target,
+                                const char *arguments)
+{
+    char *ctcp_type, *ctcp_args, *ctcp_args_no_colors;
+
+    if (!ctxt || !arguments || (arguments[0] != '\001'))
+        return;
+
+    irc_ctcp_parse_type_arguments (arguments, &ctcp_type, &ctcp_args);
+
+    if (ctcp_type)
+    {
+        ctcp_args_no_colors = (ctcp_args) ?
+            irc_color_decode (ctcp_args, 1) : NULL;
+        irc_ctcp_display_reply_to_nick_internal (ctxt, target, ctcp_type,
+                                                 ctcp_args_no_colors);
+        free (ctcp_args_no_colors);
+    }
+
+    free (ctcp_type);
+    free (ctcp_args);
+}
+
+/*
+ * Replies to CTCP from a nick and displays reply.
  */
 
 void
 irc_ctcp_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
-                        struct t_irc_channel *channel,
                         const char *ctcp,
                         const char *arguments)
 {
     struct t_arraylist *list_messages;
-    int i, list_size;
-    char *msg_color, *dup_ctcp, *dup_ctcp_upper, *dup_args;
+    int i, list_size, length;
+    char *dup_ctcp, *dup_ctcp_upper, *dup_args, *message;
     const char *ptr_message;
 
     dup_ctcp = NULL;
@@ -339,10 +434,10 @@ irc_ctcp_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
     list_messages = NULL;
 
     /*
-     * replace any "\01" by a space to prevent any firewall attack via
+     * replace any "\001" by a space to prevent any firewall attack via
      * nf_conntrack_irc (CVE-2022-2663)
      */
-    dup_ctcp = weechat_string_replace (ctcp, "\01", " ");
+    dup_ctcp = weechat_string_replace (ctcp, "\001", " ");
     if (!dup_ctcp)
         goto end;
 
@@ -353,10 +448,10 @@ irc_ctcp_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
     if (arguments)
     {
         /*
-         * replace any "\01" by a space to prevent any firewall attack via
+         * replace any "\001" by a space to prevent any firewall attack via
          * nf_conntrack_irc (CVE-2022-2663)
          */
-        dup_args = weechat_string_replace (arguments, "\01", " ");
+        dup_args = weechat_string_replace (arguments, "\001", " ");
         if (!dup_args)
             goto end;
     }
@@ -366,7 +461,7 @@ irc_ctcp_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
         IRC_SERVER_SEND_OUTQ_PRIO_LOW | IRC_SERVER_SEND_RETURN_LIST
         | IRC_SERVER_SEND_MULTILINE,
         NULL,
-        "NOTICE %s :\01%s%s%s\01",
+        "NOTICE %s :\001%s%s%s\001",
         ctxt->nick,
         dup_ctcp_upper,
         (dup_args) ? " " : "",
@@ -374,7 +469,8 @@ irc_ctcp_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
     if (!list_messages)
         goto end;
 
-    if (weechat_config_boolean (irc_config_look_display_ctcp_reply))
+    if (weechat_config_boolean (irc_config_look_display_ctcp_reply)
+        && !weechat_hashtable_has_key (ctxt->server->cap_list, "echo-message"))
     {
         list_size = weechat_arraylist_size (list_messages);
         for (i = 0; i < list_size; i++)
@@ -382,42 +478,24 @@ irc_ctcp_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
             ptr_message = (const char *)weechat_arraylist_get (list_messages, i);
             if (!ptr_message)
                 break;
-            msg_color = irc_color_decode (ptr_message, 1);
-            if (!msg_color)
-                break;
-            weechat_printf_date_tags (
-                irc_msgbuffer_get_target_buffer (
-                    ctxt->server, ctxt->nick,
-                    NULL,
-                    "ctcp",
-                    (channel) ? channel->buffer : NULL),
-                0,
-                irc_protocol_tags (ctxt,
-                                   "irc_ctcp,irc_ctcp_reply,self_msg,"
-                                   "notify_none,no_highlight"),
-                _("%sCTCP reply to %s%s%s: %s%s%s%s%s"),
-                weechat_prefix ("network"),
-                irc_nick_color_for_msg (ctxt->server, 0, NULL, ctxt->nick),
-                ctxt->nick,
-                IRC_COLOR_RESET,
-                IRC_COLOR_CHAT_CHANNEL,
-                dup_ctcp_upper,
-                (msg_color[0]) ? IRC_COLOR_RESET : "",
-                (msg_color[0]) ? " " : "",
-                msg_color);
-            free (msg_color);
+            /* build arguments: '\001' + CTCP + ' ' + message + '\001' */
+            length = 1 + strlen (dup_ctcp_upper) + 1 + strlen (ptr_message) + 1 + 1;
+            message = malloc (length);
+            if (message)
+            {
+                snprintf (message, length,
+                          "\001%s %s\001", dup_ctcp_upper, ptr_message);
+                irc_ctcp_display_reply_to_nick (ctxt, ctxt->nick, message);
+                free (message);
+            }
         }
     }
 
 end:
-    if (dup_ctcp)
-        free (dup_ctcp);
-    if (dup_ctcp_upper)
-        free (dup_ctcp_upper);
-    if (dup_args)
-        free (dup_args);
-    if (list_messages)
-        weechat_arraylist_free (list_messages);
+    free (dup_ctcp);
+    free (dup_ctcp_upper);
+    free (dup_args);
+    weechat_arraylist_free (list_messages);
 }
 
 /*
@@ -524,7 +602,7 @@ irc_ctcp_get_supported_ctcp (struct t_irc_server *server)
                 (const char *)weechat_arraylist_get (list_ctcp, i));
             if (ctcp_upper)
             {
-                if (*result[0])
+                if ((*result)[0])
                     weechat_string_dyn_concat (result, " ", -1);
                 weechat_string_dyn_concat (result, ctcp_upper, -1);
                 free (ctcp_upper);
@@ -634,8 +712,7 @@ irc_ctcp_eval_reply (struct t_irc_server *server, const char *format)
                       buf_uname->machine);
             weechat_hashtable_set (extra_vars, "osinfo", buf);
         }
-        if (buf_uname)
-            free (buf_uname);
+        free (buf_uname);
     }
 
     /*
@@ -701,10 +778,8 @@ irc_ctcp_eval_reply (struct t_irc_server *server, const char *format)
 
     value = weechat_string_eval_expression (format, NULL, extra_vars, NULL);
 
-    if (info_version)
-        free (info_version);
-    if (info_version_git)
-        free (info_version_git);
+    free (info_version);
+    free (info_version_git);
 
     weechat_hashtable_free (extra_vars);
 
@@ -919,9 +994,7 @@ irc_ctcp_recv_dcc (struct t_irc_protocol_ctxt *ctxt, const char *arguments)
                                          WEECHAT_HOOK_SIGNAL_STRING,
                                          (void *)ctxt->irc_message);
 
-        if (filename)
-            free (filename);
-
+        free (filename);
         free (dcc_args);
     }
     else if (strncmp (arguments, "RESUME ", 7) == 0)
@@ -1065,9 +1138,7 @@ irc_ctcp_recv_dcc (struct t_irc_protocol_ctxt *ctxt, const char *arguments)
                                          WEECHAT_HOOK_SIGNAL_STRING,
                                          (void *)ctxt->irc_message);
 
-        if (filename)
-            free (filename);
-
+        free (filename);
         free (dcc_args);
     }
     else if (strncmp (arguments, "ACCEPT ", 7) == 0)
@@ -1211,9 +1282,7 @@ irc_ctcp_recv_dcc (struct t_irc_protocol_ctxt *ctxt, const char *arguments)
                                          WEECHAT_HOOK_SIGNAL_STRING,
                                          (void *)ctxt->irc_message);
 
-        if (filename)
-            free (filename);
-
+        free (filename);
         free (dcc_args);
     }
     else if (strncmp (arguments, "CHAT ", 5) == 0)
@@ -1350,7 +1419,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
 
     while (ptr_args && ptr_args[0])
     {
-        pos_end = strrchr (ptr_args + 1, '\01');
+        pos_end = strrchr (ptr_args + 1, '\001');
         if (pos_end)
             pos_end[0] = '\0';
 
@@ -1412,7 +1481,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
                         ctxt->nick,
                         (pos_args) ? IRC_COLOR_RESET : "",
                         (pos_args) ? " " : "",
-                        (pos_args) ? pos_args : "");
+                        (pos_args) ? IRC_COLOR_MSG(pos_args) : "");
                 }
                 else
                 {
@@ -1433,10 +1502,9 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
                         ctxt->nick,
                         (pos_args) ? IRC_COLOR_RESET : "",
                         (pos_args) ? " " : "",
-                        (pos_args) ? pos_args : "");
+                        (pos_args) ? IRC_COLOR_MSG(pos_args) : "");
                 }
-                if (nick_color)
-                    free (nick_color);
+                free (nick_color);
             }
             else
             {
@@ -1477,7 +1545,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
                         ctxt->nick,
                         (pos_args) ? IRC_COLOR_RESET : "",
                         (pos_args) ? " " : "",
-                        (pos_args) ? pos_args : "");
+                        (pos_args) ? IRC_COLOR_MSG(pos_args) : "");
                     (void) weechat_hook_signal_send ("irc_pv",
                                                      WEECHAT_HOOK_SIGNAL_STRING,
                                                      (void *)ctxt->irc_message);
@@ -1490,7 +1558,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
             reply = irc_ctcp_get_reply (ctxt->server, ptr_args + 1);
             irc_ctcp_display_request (ctxt, channel,
                                       ptr_args + 1,
-                                      pos_args, reply);
+                                      IRC_COLOR_MSG(pos_args), reply);
             if (!reply || reply[0])
             {
                 if (reply)
@@ -1498,15 +1566,13 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
                     reply_eval = irc_ctcp_eval_reply (ctxt->server, reply);
                     if (reply_eval)
                     {
-                        irc_ctcp_reply_to_nick (ctxt, channel, ptr_args + 1,
-                                                reply_eval);
+                        irc_ctcp_reply_to_nick (ctxt, ptr_args + 1, reply_eval);
                         free (reply_eval);
                     }
                 }
                 else
                 {
-                    irc_ctcp_reply_to_nick (ctxt, channel, ptr_args + 1,
-                                            pos_args);
+                    irc_ctcp_reply_to_nick (ctxt, ptr_args + 1, pos_args);
                 }
             }
         }
@@ -1522,7 +1588,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
             if (reply)
             {
                 irc_ctcp_display_request (ctxt, channel,
-                                          ptr_args + 1, pos_args,
+                                          ptr_args + 1, IRC_COLOR_MSG(pos_args),
                                           reply);
 
                 if (reply[0])
@@ -1530,8 +1596,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
                     reply_eval = irc_ctcp_eval_reply (ctxt->server, reply);
                     if (reply_eval)
                     {
-                        irc_ctcp_reply_to_nick (ctxt, channel, ptr_args + 1,
-                                                reply_eval);
+                        irc_ctcp_reply_to_nick (ctxt, ptr_args + 1, reply_eval);
                         free (reply_eval);
                     }
                 }
@@ -1556,7 +1621,7 @@ irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
                         ptr_args + 1,
                         (pos_args) ? IRC_COLOR_RESET : "",
                         (pos_args) ? " " : "",
-                        (pos_args) ? pos_args : "");
+                        (pos_args) ? IRC_COLOR_MSG(pos_args) : "");
                 }
             }
         }
@@ -1583,7 +1648,7 @@ irc_ctcp_send (struct t_irc_server *server,
                       IRC_SERVER_SEND_OUTQ_PRIO_HIGH
                       | IRC_SERVER_SEND_MULTILINE,
                       NULL,
-                      "PRIVMSG %s :\01%s%s%s\01",
+                      "PRIVMSG %s :\001%s%s%s\001",
                       target,
                       type,
                       (args) ? " " : "",
