@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -24,6 +24,7 @@
 
 struct t_irc_server;
 struct t_irc_channel;
+struct t_irc_protocol_ctxt;
 
 struct t_irc_ctcp_reply
 {
@@ -37,21 +38,19 @@ extern char *irc_ctcp_convert_legacy_format (const char *format);
 extern const char *irc_ctcp_get_default_reply (const char *ctcp);
 extern const char *irc_ctcp_get_reply (struct t_irc_server *server,
                                        const char *ctcp);
-extern void irc_ctcp_display_reply_from_nick (struct t_irc_server *server,
-                                              time_t date,
-                                              struct t_hashtable *tags,
-                                              const char *command,
-                                              const char *nick,
-                                              const char *address,
+extern void irc_ctcp_parse_type_arguments (const char *message,
+                                           char **type, char **arguments);
+extern void irc_ctcp_display_reply_from_nick (struct t_irc_protocol_ctxt *ctxt,
                                               const char *arguments);
+extern void irc_ctcp_display_reply_to_nick (struct t_irc_protocol_ctxt *ctxt,
+                                            const char *target,
+                                            const char *arguments);
 extern char *irc_ctcp_eval_reply (struct t_irc_server *server,
                                   const char *format);
-extern void irc_ctcp_recv (struct t_irc_server *server, time_t date,
-                           struct t_hashtable *tags, const char *command,
-                           struct t_irc_channel *channel, const char *target,
-                           const char *address, const char *nick,
-                           const char *remote_nick, const char *arguments,
-                           const char *message);
+extern void irc_ctcp_recv (struct t_irc_protocol_ctxt *ctxt,
+                           struct t_irc_channel *channel,
+                           const char *remote_nick,
+                           const char *arguments);
 extern void irc_ctcp_send (struct t_irc_server *server,
                            const char *target, const char *type,
                            const char *args);
