@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -22,10 +22,13 @@
 
 #include <time.h>
 
+struct t_hashtable;
 struct t_gui_buffer;
 
 extern void irc_input_user_message_display (struct t_irc_server *server,
                                             time_t date,
+                                            int date_usec,
+                                            struct t_hashtable *tags,
                                             const char *target,
                                             const char *address,
                                             const char *command,
