@@ -250,16 +250,15 @@ irc_nick_set_host (struct t_irc_nick *nick, const char *host)
     }
 
     /* update the host in nick */
-    if (nick->host)
-        free (nick->host);
+    free (nick->host);
     nick->host = (host) ? strdup (host) : NULL;
 }
 
 /*
- * Checks if nick is "op" or higher than "op", like channel admin/owner.
+ * Checks if nick is "op" or above "op", like channel admin/owner.
  *
  * Returns:
- *   1: nick is "op" or higher
+ *   1: nick is "op" or above
  *   0: nick is not op
  */
 
@@ -422,8 +421,7 @@ irc_nick_nicklist_add (struct t_irc_server *server,
                                nick->prefix,
                                irc_nick_get_prefix_color_name (server, nick->prefix[0]),
                                1);
-    if (color)
-        free (color);
+    free (color);
 }
 
 /*
@@ -513,49 +511,32 @@ irc_nick_nicklist_set_color_all ()
             {
                 color = irc_nick_get_color_for_nicklist (ptr_server, ptr_nick);
                 irc_nick_nicklist_set (ptr_channel, ptr_nick, "color", color);
-                if (color)
-                    free (color);
+                free (color);
             }
         }
     }
 }
 
 /*
- * Adds a new nick in channel.
+ * Adds a new nick in channel, but do not update the buffer nicklist.
+ * This function is only called by the function `irc_nick_new` (below) and
+ * when restoring nicks after upgrade: in this case we want to just add nick
+ * in channel nicks without changing anything in the buffer nicklist,
+ * to preserve same identifiers).
  *
  * Returns pointer to new nick, NULL if error.
  */
 
 struct t_irc_nick *
-irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
-              const char *nickname, const char *host, const char *prefixes,
-              int away, const char *account, const char *realname)
+irc_nick_new_in_channel (struct t_irc_server *server,
+                         struct t_irc_channel *channel,
+                         const char *nickname, const char *host,
+                         const char *prefixes, int away, const char *account,
+                         const char *realname)
 {
-    struct t_irc_nick *new_nick, *ptr_nick;
+    struct t_irc_nick *new_nick;
     int length;
 
-    if (!nickname || !nickname[0])
-        return NULL;
-
-    if (!channel->nicks)
-        irc_channel_add_nicklist_groups (server, channel);
-
-    /* nick already exists on this channel? */
-    ptr_nick = irc_nick_search (server, channel, nickname);
-    if (ptr_nick)
-    {
-        /* remove old nick from nicklist */
-        irc_nick_nicklist_remove (server, channel, ptr_nick);
-
-        /* update nick prefixes */
-        irc_nick_set_prefixes (server, ptr_nick, prefixes);
-
-        /* add new nick in nicklist */
-        irc_nick_nicklist_add (server, channel, ptr_nick);
-
-        return ptr_nick;
-    }
-
     /* alloc memory for new nick */
     if ((new_nick = malloc (sizeof (*new_nick))) == NULL)
         return NULL;
@@ -570,18 +551,12 @@ irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
     new_nick->prefix = malloc (2);
     if (!new_nick->name || !new_nick->prefixes || !new_nick->prefix)
     {
-        if (new_nick->name)
-            free (new_nick->name);
-        if (new_nick->host)
-            free (new_nick->host);
-        if (new_nick->account)
-            free (new_nick->account);
-        if (new_nick->realname)
-            free (new_nick->realname);
-        if (new_nick->prefixes)
-            free (new_nick->prefixes);
-        if (new_nick->prefix)
-            free (new_nick->prefix);
+        free (new_nick->name);
+        free (new_nick->host);
+        free (new_nick->account);
+        free (new_nick->realname);
+        free (new_nick->prefixes);
+        free (new_nick->prefix);
         free (new_nick);
         return NULL;
     }
@@ -609,6 +584,49 @@ irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
 
     channel->nick_completion_reset = 1;
 
+    return new_nick;
+}
+
+/*
+ * Adds a new nick in channel.
+ *
+ * Returns pointer to new nick, NULL if error.
+ */
+
+struct t_irc_nick *
+irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
+              const char *nickname, const char *host, const char *prefixes,
+              int away, const char *account, const char *realname)
+{
+    struct t_irc_nick *new_nick, *ptr_nick;
+
+    if (!nickname || !nickname[0])
+        return NULL;
+
+    if (!channel->nicks)
+        irc_channel_add_nicklist_groups (server, channel);
+
+    /* nick already exists on this channel? */
+    ptr_nick = irc_nick_search (server, channel, nickname);
+    if (ptr_nick)
+    {
+        /* remove old nick from nicklist */
+        irc_nick_nicklist_remove (server, channel, ptr_nick);
+
+        /* update nick prefixes */
+        irc_nick_set_prefixes (server, ptr_nick, prefixes);
+
+        /* add new nick in nicklist */
+        irc_nick_nicklist_add (server, channel, ptr_nick);
+
+        return ptr_nick;
+    }
+
+    new_nick = irc_nick_new_in_channel (server, channel, nickname, host,
+                                        prefixes, away, account, realname);
+    if (!new_nick)
+        return NULL;
+
     /* add nick to buffer nicklist */
     irc_nick_nicklist_add (server, channel, new_nick);
 
@@ -635,11 +653,9 @@ irc_nick_change (struct t_irc_server *server, struct t_irc_channel *channel,
         irc_channel_nick_speaking_rename (channel, nick->name, new_nick);
 
     /* change nickname */
-    if (nick->name)
-        free (nick->name);
+    free (nick->name);
     nick->name = strdup (new_nick);
-    if (nick->color)
-        free (nick->color);
+    free (nick->color);
     if (nick_is_me)
         nick->color = strdup (IRC_COLOR_CHAT_NICK_SELF);
     else
@@ -676,7 +692,7 @@ irc_nick_set_mode (struct t_irc_server *server, struct t_irc_channel *channel,
 
     if (irc_server_strcasecmp (server, nick->name, server->nick) == 0)
     {
-        weechat_bar_item_update ("input_prompt");
+        irc_server_set_buffer_input_prompt (server);
         weechat_bar_item_update ("irc_nick");
         weechat_bar_item_update ("irc_nick_host");
     }
@@ -762,20 +778,13 @@ irc_nick_free (struct t_irc_server *server, struct t_irc_channel *channel,
     channel->nicks_count--;
 
     /* free data */
-    if (nick->name)
-        free (nick->name);
-    if (nick->host)
-        free (nick->host);
-    if (nick->prefixes)
-        free (nick->prefixes);
-    if (nick->prefix)
-        free (nick->prefix);
-    if (nick->account)
-        free (nick->account);
-    if (nick->realname)
-        free (nick->realname);
-    if (nick->color)
-        free (nick->color);
+    free (nick->name);
+    free (nick->host);
+    free (nick->prefixes);
+    free (nick->prefix);
+    free (nick->account);
+    free (nick->realname);
+    free (nick->color);
 
     free (nick);
 
@@ -804,6 +813,9 @@ irc_nick_free_all (struct t_irc_server *server, struct t_irc_channel *channel)
 
     /* should be zero, but prevent any bug :D */
     channel->nicks_count = 0;
+
+    irc_channel_set_buffer_modes (server, channel);
+    irc_channel_set_buffer_input_prompt (server, channel);
 }
 
 /*
@@ -910,8 +922,7 @@ irc_nick_set_away (struct t_irc_server *server, struct t_irc_channel *channel,
         nick->away = is_away;
         color = irc_nick_get_color_for_nicklist (server, nick);
         irc_nick_nicklist_set (channel, nick, "color", color);
-        if (color)
-            free (color);
+        free (color);
     }
 }
 
@@ -994,8 +1005,7 @@ irc_nick_as_prefix (struct t_irc_server *server, struct t_irc_nick *nick,
               color,
               (nick) ? nick->name : nickname);
 
-    if (color)
-        free (color);
+    free (color);
 
     return result;
 }
@@ -1033,8 +1043,7 @@ irc_nick_color_for_msg (struct t_irc_server *server, int server_message,
         snprintf (color[index_color], sizeof (color[index_color]),
                   "%s",
                   color_found);
-        if (color_found)
-            free (color_found);
+        free (color_found);
         return color[index_color];
     }
 
@@ -1200,14 +1209,14 @@ void
 irc_nick_print_log (struct t_irc_nick *nick)
 {
     weechat_log_printf ("");
-    weechat_log_printf ("    => nick %s (addr:0x%lx):",    nick->name, nick);
-    weechat_log_printf ("         host . . . . . : '%s'",  nick->host);
-    weechat_log_printf ("         prefixes . . . : '%s'",  nick->prefixes);
-    weechat_log_printf ("         prefix . . . . : '%s'",  nick->prefix);
-    weechat_log_printf ("         away . . . . . : %d",    nick->away);
-    weechat_log_printf ("         account. . . . : '%s'",  nick->account);
-    weechat_log_printf ("         realname . . . : '%s'",  nick->realname);
-    weechat_log_printf ("         color. . . . . : '%s'",  nick->color);
-    weechat_log_printf ("         prev_nick. . . : 0x%lx", nick->prev_nick);
-    weechat_log_printf ("         next_nick. . . : 0x%lx", nick->next_nick);
+    weechat_log_printf ("    => nick %s (addr:%p):", nick->name, nick);
+    weechat_log_printf ("         host . . . . . : '%s'", nick->host);
+    weechat_log_printf ("         prefixes . . . : '%s'", nick->prefixes);
+    weechat_log_printf ("         prefix . . . . : '%s'", nick->prefix);
+    weechat_log_printf ("         away . . . . . : %d", nick->away);
+    weechat_log_printf ("         account. . . . : '%s'", nick->account);
+    weechat_log_printf ("         realname . . . : '%s'", nick->realname);
+    weechat_log_printf ("         color. . . . . : '%s'", nick->color);
+    weechat_log_printf ("         prev_nick. . . : %p", nick->prev_nick);
+    weechat_log_printf ("         next_nick. . . : %p", nick->next_nick);
 }
