@@ -390,6 +390,8 @@ irc_raw_open (int switch_to_buffer)
                 NULL, NULL);
             if (buffer_props)
             {
+                weechat_hashtable_set (buffer_props,
+                                       "short_name", IRC_RAW_BUFFER_NAME);
                 weechat_hashtable_set (buffer_props,
                                        "localvar_set_type", "debug");
                 weechat_hashtable_set (buffer_props,
@@ -412,12 +414,6 @@ irc_raw_open (int switch_to_buffer)
             if (!irc_raw_buffer)
                 return;
 
-            if (!weechat_buffer_get_integer (irc_raw_buffer, "short_name_is_set"))
-            {
-                weechat_buffer_set (irc_raw_buffer, "short_name",
-                                    IRC_RAW_BUFFER_NAME);
-            }
-
             irc_raw_set_localvar_filter ();
 
             irc_raw_refresh (0);
