@@ -1,7 +1,7 @@
 /*
  * logger.c - logger plugin for WeeChat: save buffer lines to disk files
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -25,6 +25,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <time.h>
+#include <sys/time.h>
 
 #include "../weechat-plugin.h"
 #include "logger.h"
@@ -94,13 +95,10 @@ logger_check_conditions (struct t_gui_buffer *buffer, const char *conditions)
     result = weechat_string_eval_expression (conditions,
                                              pointers, NULL, options);
     condition_ok = (result && (strcmp (result, "1") == 0));
-    if (result)
-        free (result);
+    free (result);
 
-    if (pointers)
-        weechat_hashtable_free (pointers);
-    if (options)
-        weechat_hashtable_free (options);
+    weechat_hashtable_free (pointers);
+    weechat_hashtable_free (options);
 
     return condition_ok;
 }
@@ -137,8 +135,7 @@ logger_get_file_path ()
         weechat_hashtable_set (options, "directory", "data");
     path = weechat_string_eval_path_home (
         weechat_config_string (logger_config_file_path), NULL, NULL, options);
-    if (options)
-        weechat_hashtable_free (options);
+    weechat_hashtable_free (options);
     if (!path)
         goto end;
 
@@ -150,7 +147,7 @@ logger_get_file_path ()
     seconds = time (NULL);
     date_tmp = localtime (&seconds);
     path2[0] = '\0';
-    if (strftime (path2, length - 1, path, date_tmp) == 0)
+    if (strftime (path2, length, path, date_tmp) == 0)
         path2[0] = '\0';
 
     if (weechat_logger_plugin->debug)
@@ -161,8 +158,7 @@ logger_get_file_path ()
     }
 
 end:
-    if (path)
-        free (path);
+    free (path);
     return path2;
 }
 
@@ -186,7 +182,15 @@ logger_create_directory ()
     if (file_path)
     {
         if (!weechat_mkdir_parents (file_path, 0700))
+        {
+            weechat_printf_date_tags (
+                NULL, 0, "no_log",
+                _("%s%s: unable to create directory for logs "
+                  "(\"%s\")"),
+                weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
+                file_path);
             rc = 0;
+        }
         free (file_path);
     }
     else
@@ -378,15 +382,15 @@ logger_get_mask_expanded (struct t_gui_buffer *buffer, const char *mask)
     seconds = time (NULL);
     date_tmp = localtime (&seconds);
     mask2[0] = '\0';
-    if (strftime (mask2, length - 1, mask, date_tmp) == 0)
+    if (strftime (mask2, length, mask, date_tmp) == 0)
         mask2[0] = '\0';
 
     /*
-     * we first replace directory separator (commonly '/') by \01 because
+     * we first replace directory separator (commonly '/') by \001 because
      * buffer mask can contain this char, and will be replaced by replacement
      * char ('_' by default)
      */
-    mask3 = weechat_string_replace (mask2, dir_separator, "\01");
+    mask3 = weechat_string_replace (mask2, dir_separator, "\001");
     if (!mask3)
         goto end;
 
@@ -411,7 +415,7 @@ logger_get_mask_expanded (struct t_gui_buffer *buffer, const char *mask)
 
     /* restore directory separator */
     mask7 = weechat_string_replace (mask6,
-                                    "\01", dir_separator);
+                                    "\001", dir_separator);
     if (!mask7)
         goto end;
 
@@ -433,18 +437,12 @@ logger_get_mask_expanded (struct t_gui_buffer *buffer, const char *mask)
 
 end:
     free (dir_separator);
-    if (mask2)
-        free (mask2);
-    if (mask3)
-        free (mask3);
-    if (mask4)
-        free (mask4);
-    if (mask5)
-        free (mask5);
-    if (mask6)
-        free (mask6);
-    if (mask7)
-        free (mask7);
+    free (mask2);
+    free (mask3);
+    free (mask4);
+    free (mask5);
+    free (mask6);
+    free (mask7);
 
     return mask8;
 }
@@ -506,10 +504,8 @@ logger_get_filename (struct t_gui_buffer *buffer)
 
 end:
     free (dir_separator);
-    if (mask_expanded)
-        free (mask_expanded);
-    if (file_path)
-        free (file_path);
+    free (mask_expanded);
+    free (file_path);
 
     return res;
 }
@@ -695,13 +691,13 @@ logger_get_line_tag_info (int tags_count, const char **tags,
 
 int
 logger_print_cb (const void *pointer, void *data,
-                 struct t_gui_buffer *buffer, time_t date,
+                 struct t_gui_buffer *buffer, time_t date, int date_usec,
                  int tags_count, const char **tags,
                  int displayed, int highlight,
                  const char *prefix, const char *message)
 {
     struct t_logger_buffer *ptr_logger_buffer;
-    struct tm *date_tmp;
+    struct timeval tv;
     char buf_time[256], *prefix_ansi, *message_ansi;
     const char *ptr_prefix, *ptr_message;
     int line_log_level, prefix_is_nick, color_lines;
@@ -740,15 +736,12 @@ logger_print_cb (const void *pointer, void *data,
             ptr_prefix = prefix;
             ptr_message = message;
         }
-        buf_time[0] = '\0';
-        date_tmp = localtime (&date);
-        if (date_tmp)
-        {
-            if (strftime (buf_time, sizeof (buf_time) - 1,
-                          weechat_config_string (logger_config_file_time_format),
-                          date_tmp) == 0)
-                buf_time[0] = '\0';
-        }
+        tv.tv_sec = date;
+        tv.tv_usec = date_usec;
+        weechat_util_strftimeval (
+            buf_time, sizeof (buf_time),
+            weechat_config_string (logger_config_file_time_format),
+            &tv);
 
         logger_buffer_write_line (
             ptr_logger_buffer,
@@ -760,10 +753,8 @@ logger_print_cb (const void *pointer, void *data,
             (color_lines) ? "\x1B[0m" : "",
             ptr_message);
 
-        if (prefix_ansi)
-            free (prefix_ansi);
-        if (message_ansi)
-            free (message_ansi);
+        free (prefix_ansi);
+        free (message_ansi);
     }
 
     return WEECHAT_RC_OK;
