@@ -62,18 +62,25 @@ function weechat_config_option_set(string $p0, string $p1, int $p2): int {}
 function weechat_config_option_set_null(string $p0, int $p1): int {}
 function weechat_config_option_unset(string $p0): int {}
 function weechat_config_option_rename(string $p0, string $p1): int {}
+function weechat_config_option_get_string(string $p0, string $p1): string {}
+function weechat_config_option_get_pointer(string $p0, string $p1): string {}
 function weechat_config_option_is_null(string $p0): int {}
 function weechat_config_option_default_is_null(string $p0): int {}
 function weechat_config_boolean(string $p0): int {}
 function weechat_config_boolean_default(string $p0): int {}
+function weechat_config_boolean_inherited(string $p0): int {}
 function weechat_config_integer(string $p0): int {}
 function weechat_config_integer_default(string $p0): int {}
+function weechat_config_integer_inherited(string $p0): int {}
 function weechat_config_string(string $p0): string {}
 function weechat_config_string_default(string $p0): string {}
+function weechat_config_string_inherited(string $p0): string {}
 function weechat_config_color(string $p0): string {}
 function weechat_config_color_default(string $p0): string {}
+function weechat_config_color_inherited(string $p0): string {}
 function weechat_config_enum(string $p0): int {}
 function weechat_config_enum_default(string $p0): int {}
+function weechat_config_enum_inherited(string $p0): int {}
 function weechat_config_write_option(string $p0, string $p1): int {}
 function weechat_config_write_line(string $p0, string $p1, string $p2): int {}
 function weechat_config_write(string $p0): int {}
@@ -142,6 +149,7 @@ function weechat_buffer_get_pointer(string $p0, string $p1): string {}
 function weechat_buffer_set(string $p0, string $p1, string $p2): int {}
 function weechat_buffer_string_replace_local_var(string $p0, string $p1): string {}
 function weechat_buffer_match_list(string $p0, string $p1): int {}
+function weechat_line_search_by_id(string $p0, int $p1): string {}
 function weechat_current_window(): string {}
 function weechat_window_search_with_buffer(string $p0): string {}
 function weechat_window_get_integer(string $p0, string $p1): int {}
@@ -211,6 +219,7 @@ function weechat_hdata_search(string $p0, string $p1, string $p2, array $p3, arr
 function weechat_hdata_char(string $p0, string $p1, string $p2): int {}
 function weechat_hdata_integer(string $p0, string $p1, string $p2): int {}
 function weechat_hdata_long(string $p0, string $p1, string $p2): int {}
+function weechat_hdata_longlong(string $p0, string $p1, string $p2): int {}
 function weechat_hdata_string(string $p0, string $p1, string $p2): string {}
 function weechat_hdata_pointer(string $p0, string $p1, string $p2): string {}
 function weechat_hdata_time(string $p0, string $p1, string $p2): int {}
