@@ -1,7 +1,7 @@
 /*
  * plugin-api.c - extra functions for plugin API
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -28,14 +28,14 @@
 #include <gcrypt.h>
 
 #include "../core/weechat.h"
-#include "../core/wee-config.h"
-#include "../core/wee-crypto.h"
-#include "../core/wee-hashtable.h"
-#include "../core/wee-hook.h"
-#include "../core/wee-infolist.h"
-#include "../core/wee-input.h"
-#include "../core/wee-proxy.h"
-#include "../core/wee-string.h"
+#include "../core/core-config.h"
+#include "../core/core-crypto.h"
+#include "../core/core-hashtable.h"
+#include "../core/core-hook.h"
+#include "../core/core-infolist.h"
+#include "../core/core-input.h"
+#include "../core/core-proxy.h"
+#include "../core/core-string.h"
 #include "../gui/gui-bar.h"
 #include "../gui/gui-bar-item.h"
 #include "../gui/gui-bar-window.h"
@@ -67,9 +67,7 @@ plugin_api_charset_set (struct t_weechat_plugin *plugin, const char *charset)
     if (!plugin || !charset)
         return;
 
-    if (plugin->charset)
-        free (plugin->charset);
-
+    free (plugin->charset);
     plugin->charset = (charset) ? strdup (charset) : NULL;
 }
 
@@ -433,8 +431,7 @@ plugin_api_command_options (struct t_weechat_plugin *plugin,
                              split_newline,
                              delay);
 
-    if (command2)
-        free (command2);
+    free (command2);
 
     return rc;
 }
@@ -450,6 +447,25 @@ plugin_api_command (struct t_weechat_plugin *plugin,
     return plugin_api_command_options (plugin, buffer, command, NULL);
 }
 
+/*
+ * Modifier callback: decodes WeeChat colors: converts WeeChat color codes to
+ * WeeChat a replacement string.
+ */
+
+char *
+plugin_api_modifier_color_decode_cb (const void *pointer, void *data,
+                                     const char *modifier,
+                                     const char *modifier_data,
+                                     const char *string)
+{
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) modifier;
+
+    return gui_color_decode (string, modifier_data);
+}
+
 /*
  * Modifier callback: decodes ANSI colors: converts ANSI color codes to WeeChat
  * colors (or removes them).
@@ -528,8 +544,7 @@ plugin_api_modifier_eval_path_home_cb (const void *pointer, void *data,
 
     result = string_eval_path_home (string, NULL, NULL, options);
 
-    if (options)
-        hashtable_free (options);
+    hashtable_free (options);
 
     return result;
 }
@@ -681,6 +696,8 @@ void
 plugin_api_init ()
 {
     /* WeeChat core modifiers */
+    hook_modifier (NULL, "color_decode",
+                   &plugin_api_modifier_color_decode_cb, NULL, NULL);
     hook_modifier (NULL, "color_decode_ansi",
                    &plugin_api_modifier_color_decode_ansi_cb, NULL, NULL);
     hook_modifier (NULL, "color_encode_ansi",
