@@ -41,9 +41,7 @@ plugin_script_api_charset_set (struct t_plugin_script *script,
     if (!script)
         return;
 
-    if (script->charset)
-        free (script->charset);
-
+    free (script->charset);
     script->charset = (charset) ? strdup (charset) : NULL;
 }
 
@@ -74,8 +72,7 @@ plugin_script_api_string_match_list (struct t_weechat_plugin *weechat_plugin,
                                        (const char **)list_masks,
                                        case_sensitive);
 
-    if (list_masks)
-        weechat_string_free_split (list_masks);
+    weechat_string_free_split (list_masks);
 
     return match;
 }
@@ -248,16 +245,11 @@ plugin_script_api_config_new_section (struct t_weechat_plugin *weechat_plugin,
 
     if (!new_section)
     {
-        if (function_and_data_read)
-            free (function_and_data_read);
-        if (function_and_data_write)
-            free (function_and_data_write);
-        if (function_and_data_write_default)
-            free (function_and_data_write_default);
-        if (function_and_data_create_option)
-            free (function_and_data_create_option);
-        if (function_and_data_delete_option)
-            free (function_and_data_delete_option);
+        free (function_and_data_read);
+        free (function_and_data_write);
+        free (function_and_data_write_default);
+        free (function_and_data_create_option);
+        free (function_and_data_delete_option);
     }
 
     return new_section;
@@ -328,12 +320,9 @@ plugin_script_api_config_new_option (struct t_weechat_plugin *weechat_plugin,
 
     if (!new_option)
     {
-        if (function_and_data_check_value)
-            free (function_and_data_check_value);
-        if (function_and_data_change)
-            free (function_and_data_change);
-        if (function_and_data_delete)
-            free (function_and_data_delete);
+        free (function_and_data_check_value);
+        free (function_and_data_change);
+        free (function_and_data_delete);
     }
 
     return new_option;
@@ -357,8 +346,7 @@ plugin_script_api_printf (struct t_weechat_plugin *weechat_plugin,
     buf2 = (script && script->charset && script->charset[0]) ?
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf (buffer, "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -384,8 +372,7 @@ plugin_script_api_printf_date_tags (struct t_weechat_plugin *weechat_plugin,
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_date_tags (buffer, date, tags,
                               "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -412,8 +399,7 @@ plugin_script_api_printf_datetime_tags (struct t_weechat_plugin *weechat_plugin,
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_datetime_tags (buffer, date, date_usec, tags,
                                   "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -437,8 +423,7 @@ plugin_script_api_printf_y (struct t_weechat_plugin *weechat_plugin,
     buf2 = (script && script->charset && script->charset[0]) ?
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_y (buffer, y, "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -464,8 +449,7 @@ plugin_script_api_printf_y_date_tags (struct t_weechat_plugin *weechat_plugin,
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_y_date_tags (buffer, y, date, tags,
                                 "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -493,8 +477,7 @@ plugin_script_api_printf_y_datetime_tags (struct t_weechat_plugin *weechat_plugi
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_printf_y_datetime_tags (buffer, y, date, date_usec, tags,
                                     "%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -517,8 +500,7 @@ plugin_script_api_log_printf (struct t_weechat_plugin *weechat_plugin,
     buf2 = (script && script->charset && script->charset[0]) ?
         weechat_iconv_to_internal (script->charset, vbuffer) : NULL;
     weechat_log_printf ("%s", (buf2) ? buf2 : vbuffer);
-    if (buf2)
-        free (buf2);
+    free (buf2);
 
     free (vbuffer);
 }
@@ -556,14 +538,9 @@ plugin_script_api_hook_command (struct t_weechat_plugin *weechat_plugin,
                                      callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -597,14 +574,9 @@ plugin_script_api_hook_command_run (struct t_weechat_plugin *weechat_plugin,
                                          callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -637,14 +609,9 @@ plugin_script_api_hook_timer (struct t_weechat_plugin *weechat_plugin,
                                    callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -678,14 +645,9 @@ plugin_script_api_hook_fd (struct t_weechat_plugin *weechat_plugin,
                                 callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -724,14 +686,9 @@ plugin_script_api_hook_process_hashtable (struct t_weechat_plugin *weechat_plugi
                                                function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -793,14 +750,9 @@ plugin_script_api_hook_url (struct t_weechat_plugin *weechat_plugin,
                                  callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -844,14 +796,9 @@ plugin_script_api_hook_connect (struct t_weechat_plugin *weechat_plugin,
                                      callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -886,14 +833,9 @@ plugin_script_api_hook_line (struct t_weechat_plugin *weechat_plugin,
                                   script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -935,14 +877,9 @@ plugin_script_api_hook_print (struct t_weechat_plugin *weechat_plugin,
                                    callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -977,14 +914,9 @@ plugin_script_api_hook_signal (struct t_weechat_plugin *weechat_plugin,
                                     function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1018,14 +950,9 @@ plugin_script_api_hook_hsignal (struct t_weechat_plugin *weechat_plugin,
                                      function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1059,14 +986,9 @@ plugin_script_api_hook_config (struct t_weechat_plugin *weechat_plugin,
                                     function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1102,14 +1024,9 @@ plugin_script_api_hook_completion (struct t_weechat_plugin *weechat_plugin,
                                         callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1144,14 +1061,9 @@ plugin_script_api_hook_modifier (struct t_weechat_plugin *weechat_plugin,
                                       callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1187,14 +1099,9 @@ plugin_script_api_hook_info (struct t_weechat_plugin *weechat_plugin,
                                   callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1234,14 +1141,9 @@ plugin_script_api_hook_info_hashtable (struct t_weechat_plugin *weechat_plugin,
                                             function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1280,14 +1182,9 @@ plugin_script_api_hook_infolist (struct t_weechat_plugin *weechat_plugin,
                                       callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1319,14 +1216,9 @@ plugin_script_api_hook_focus (struct t_weechat_plugin *weechat_plugin,
     new_hook = weechat_hook_focus (area, callback, script, function_and_data);
 
     if (new_hook)
-    {
         weechat_hook_set (new_hook, "subplugin", script->name);
-    }
     else
-    {
-        if (function_and_data)
-            free (function_and_data);
-    }
+        free (function_and_data);
 
     return new_hook;
 }
@@ -1389,10 +1281,8 @@ plugin_script_api_buffer_new_props (struct t_weechat_plugin *weechat_plugin,
     }
     else
     {
-        if (function_and_data_input)
-            free (function_and_data_input);
-        if (function_and_data_close)
-            free (function_and_data_close);
+        free (function_and_data_input);
+        free (function_and_data_close);
     }
 
     return new_buffer;
@@ -1505,8 +1395,7 @@ plugin_script_api_command_options (struct t_weechat_plugin *weechat_plugin,
                                   (command2) ? command2 : command,
                                   options);
 
-    if (command2)
-        free (command2);
+    free (command2);
 
     return rc;
 }
