@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2012 Simon Arlott
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -126,6 +126,12 @@ extern void plugin_script_api_printf_date_tags (struct t_weechat_plugin *weechat
                                                 struct t_gui_buffer *buffer,
                                                 time_t date, const char *tags,
                                                 const char *format, ...);
+extern void plugin_script_api_printf_datetime_tags (struct t_weechat_plugin *weechat_plugin,
+                                                    struct t_plugin_script *script,
+                                                    struct t_gui_buffer *buffer,
+                                                    time_t date, int date_usec,
+                                                    const char *tags,
+                                                    const char *format, ...);
 extern void plugin_script_api_printf_y (struct t_weechat_plugin *weechat_plugin,
                                         struct t_plugin_script *script,
                                         struct t_gui_buffer *buffer,
@@ -136,6 +142,13 @@ extern void plugin_script_api_printf_y_date_tags (struct t_weechat_plugin *weech
                                                   int y, time_t date,
                                                   const char *tags,
                                                   const char *format, ...);
+extern void plugin_script_api_printf_y_datetime_tags (struct t_weechat_plugin *weechat_plugin,
+                                                      struct t_plugin_script *script,
+                                                      struct t_gui_buffer *buffer,
+                                                      int y,
+                                                      time_t date, int date_usec,
+                                                      const char *tags,
+                                                      const char *format, ...);
 extern void plugin_script_api_log_printf (struct t_weechat_plugin *weechat_plugin,
                                           struct t_plugin_script *script,
                                           const char *format, ...);
@@ -256,6 +269,7 @@ extern struct t_hook *plugin_script_api_hook_print (struct t_weechat_plugin *wee
                                                                     void *data,
                                                                     struct t_gui_buffer *buffer,
                                                                     time_t date,
+                                                                    int date_usec,
                                                                     int tags_count,
                                                                     const char **tags,
                                                                     int displayed,
