@@ -1,7 +1,7 @@
 /*
  * relay-upgrade.c - save/restore relay plugin data when upgrading WeeChat
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -217,9 +217,11 @@ relay_upgrade_read_cb (const void *pointer, void *data,
                 relay_client_new_with_infolist (infolist);
                 break;
             case RELAY_UPGRADE_TYPE_RAW_MESSAGE:
-                relay_raw_message_add_to_list (weechat_infolist_time (infolist, "date"),
-                                               weechat_infolist_string (infolist, "prefix"),
-                                               weechat_infolist_string (infolist, "message"));
+                relay_raw_message_add_to_list (
+                    weechat_infolist_time (infolist, "date"),
+                    weechat_infolist_integer (infolist, "date_usec"),
+                    weechat_infolist_string (infolist, "prefix"),
+                    weechat_infolist_string (infolist, "message"));
                 break;
         }
     }
