@@ -24,6 +24,7 @@
 
 #include "../weechat-plugin.h"
 #include "relay.h"
+#include "relay-bar-item.h"
 #include "relay-buffer.h"
 #include "relay-client.h"
 #include "relay-command.h"
@@ -72,8 +73,6 @@ struct t_hdata *relay_hdata_completion = NULL;
 struct t_hdata *relay_hdata_completion_word = NULL;
 struct t_hdata *relay_hdata_hotlist = NULL;
 
-int relay_signal_upgrade_received = 0; /* signal "upgrade" received ?       */
-
 struct t_hook *relay_hook_timer = NULL;
 
 
@@ -150,12 +149,17 @@ relay_signal_upgrade_cb (const void *pointer, void *data,
     if (signal_data && (strcmp (signal_data, "save") == 0))
     {
         /* save session with a disconnected state in clients */
-        relay_upgrade_save (1);
+        if (!relay_upgrade_save (1))
+        {
+            weechat_printf (
+                NULL,
+                _("%s%s: failed to save upgrade data"),
+                weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+            return WEECHAT_RC_ERROR;
+        }
         return WEECHAT_RC_OK;
     }
 
-    relay_signal_upgrade_received = 1;
-
     /* close socket for relay servers */
     for (ptr_server = relay_servers; ptr_server;
          ptr_server = ptr_server->next_server)
@@ -202,6 +206,15 @@ relay_signal_upgrade_cb (const void *pointer, void *data,
                         NG_("client", "clients", tls_disconnected));
     }
 
+    if (!relay_upgrade_save (0))
+    {
+        weechat_printf (
+            NULL,
+            _("%s%s: failed to save upgrade data"),
+            weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+        return WEECHAT_RC_ERROR;
+    }
+
     return WEECHAT_RC_OK;
 }
 
@@ -283,8 +296,6 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     relay_hdata_completion_word = weechat_hdata_get ("completion_word");
     relay_hdata_hotlist = weechat_hdata_get ("hotlist");
 
-    relay_signal_upgrade_received = 0;
-
     if (!relay_config_init ())
         return WEECHAT_RC_ERROR;
 
@@ -297,6 +308,8 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     /* hook completions */
     relay_completion_init ();
 
+    relay_bar_item_init ();
+
     weechat_hook_signal ("upgrade", &relay_signal_upgrade_cb, NULL, NULL);
     weechat_hook_signal ("debug_dump", &relay_debug_dump_cb, NULL, NULL);
 
@@ -338,9 +351,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
 
     relay_config_write ();
 
-    if (relay_signal_upgrade_received)
-        relay_upgrade_save (0);
-    else
+    if (!weechat_relay_plugin->unload_with_upgrade)
         relay_client_disconnect_all ();
 
     relay_raw_message_free_all ();
