@@ -447,7 +447,7 @@ void
 trigger_command_error_running (struct t_trigger *trigger, const char *action)
 {
     weechat_printf_date_tags (NULL, 0, "no_trigger",
-                              _("%s%s: action \"%s\" can not be executed on "
+                              _("%s%s: action \"%s\" cannot be executed on "
                                 "trigger \"%s\" because it is currently "
                                 "running"),
                               weechat_prefix ("error"), TRIGGER_PLUGIN_NAME,
@@ -487,7 +487,7 @@ trigger_command_set_enabled (struct t_trigger *trigger,
         else if (display_error)
         {
             weechat_printf_date_tags (NULL, 0, "no_trigger",
-                                      _("%s%s: a disabled trigger can not be "
+                                      _("%s%s: a disabled trigger cannot be "
                                         "restarted"),
                                       weechat_prefix ("error"),
                                       TRIGGER_PLUGIN_NAME);
@@ -1257,7 +1257,7 @@ trigger_command_init ()
     weechat_hook_command (
         "trigger",
         N_("manage triggers, the Swiss Army knife for WeeChat"),
-        /* TRANSLATORS: only text between angle brackets (eg: "<name>") must be translated */
+        /* TRANSLATORS: only text between angle brackets (eg: "<name>") may be translated */
         N_("list [-o|-ol|-i|-il]"
            " || listfull"
            " || listdefault"
@@ -1268,11 +1268,11 @@ trigger_command_init ()
            " || input|output|recreate <name>"
            " || set <name> <option> <value>"
            " || rename|copy <name> <new_name>"
-           " || enable|disable|toggle [<name>|<mask> [<name>|<mask>...]]"
-           " || restart <name>|<mask> [<name>|<mask>...]"
+           " || enable|disable|toggle [<name>|<mask>...]"
+           " || restart <name>|<mask>..."
            " || show <name>"
-           " || del <name>|<mask> [<name>|<mask>...]"
-           " || restore <name>|<mask> [<name>|<mask>...]"
+           " || del <name>|<mask>..."
+           " || restore <name>|<mask>..."
            " || default -yes"
            " || monitor [<filter>]"),
         WEECHAT_CMD_ARGS_DESC(
