@@ -1,7 +1,7 @@
 /*
  * trigger-config.c - trigger configuration options (file trigger.conf)
  *
- * Copyright (C) 2014-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -366,7 +366,7 @@ trigger_config_create_trigger_option (const char *trigger_name, int index_option
                 trigger_config_file, trigger_config_section_trigger,
                 option_name, "boolean",
                 N_("if disabled, the hooks are removed from trigger, so it is "
-                   "not called any more"),
+                   "not called anymore"),
                 NULL, 0, 0, value, NULL, 0,
                 NULL, NULL, NULL,
                 &trigger_config_change_trigger_enabled, NULL, NULL,
@@ -532,8 +532,7 @@ trigger_config_use_temp_triggers ()
     {
         next_temp_trigger = triggers_temp->next_trigger;
 
-        if (triggers_temp->name)
-            free (triggers_temp->name);
+        free (triggers_temp->name);
         free (triggers_temp);
 
         triggers_temp = next_temp_trigger;
@@ -831,4 +830,5 @@ void
 trigger_config_free ()
 {
     weechat_config_free (trigger_config_file);
+    trigger_config_file = NULL;
 }
