@@ -1,7 +1,7 @@
 /*
  * xfer.c - file transfer and direct chat plugin for WeeChat
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -80,8 +80,6 @@ struct t_xfer *xfer_list = NULL;       /* list of files/chats               */
 struct t_xfer *last_xfer = NULL;       /* last file/chat in list            */
 int xfer_count = 0;                    /* number of xfer                    */
 
-int xfer_signal_upgrade_received = 0;  /* signal "upgrade" received ?       */
-
 void xfer_disconnect_all ();
 
 
@@ -130,12 +128,17 @@ xfer_signal_upgrade_cb (const void *pointer, void *data,
     /* only save session and continue? */
     if (signal_data && (strcmp (signal_data, "save") == 0))
     {
-        xfer_upgrade_save ();
+        if (!xfer_upgrade_save ())
+        {
+            weechat_printf (
+                NULL,
+                _("%s%s: failed to save upgrade data"),
+                weechat_prefix ("error"), XFER_PLUGIN_NAME);
+            return WEECHAT_RC_ERROR;
+        }
         return WEECHAT_RC_OK;
     }
 
-    xfer_signal_upgrade_received = 1;
-
     /*
      * TODO: do not disconnect here in case of upgrade when the save of xfers
      * in upgrade file will be implemented
@@ -144,6 +147,15 @@ xfer_signal_upgrade_cb (const void *pointer, void *data,
     /*if (signal_data && (strcmp (signal_data, "quit") == 0))*/
     xfer_disconnect_all ();
 
+    if (!xfer_upgrade_save ())
+    {
+        weechat_printf (
+            NULL,
+            _("%s%s: failed to save upgrade data"),
+            weechat_prefix ("error"), XFER_PLUGIN_NAME);
+        return WEECHAT_RC_ERROR;
+    }
+
     return WEECHAT_RC_OK;
 }
 
@@ -186,8 +198,7 @@ xfer_create_directories ()
         free (path);
     }
 
-    if (options)
-        weechat_hashtable_free (options);
+    weechat_hashtable_free (options);
 }
 
 /*
@@ -670,8 +681,7 @@ xfer_new (const char *plugin_name, const char *plugin_id,
     new_xfer->remote_nick = strdup (remote_nick);
     color = weechat_info_get ("irc_nick_color_name", remote_nick);
     new_xfer->remote_nick_color = (color) ? strdup (color) : NULL;
-    if (color)
-        free (color);
+    free (color);
     new_xfer->local_nick = (local_nick) ? strdup (local_nick) : NULL;
     new_xfer->charset_modifier = (charset_modifier) ? strdup (charset_modifier) : NULL;
     if (XFER_IS_FILE(type))
@@ -875,15 +885,13 @@ void
 xfer_set_remote_address (struct t_xfer *xfer, const struct sockaddr *address,
                          socklen_t length, const char *address_str)
 {
-    if (xfer->remote_address)
-        free (xfer->remote_address);
+    free (xfer->remote_address);
     xfer->remote_address = malloc (length);
     xfer->remote_address_length = length;
     if (xfer->remote_address)
 	memcpy (xfer->remote_address, address, length);
 
-    if (xfer->remote_address_str)
-        free (xfer->remote_address_str);
+    free (xfer->remote_address_str);
     xfer->remote_address_str = strdup ((address_str) ? address_str : "");
 }
 
@@ -894,15 +902,13 @@ void
 xfer_set_local_address (struct t_xfer *xfer, const struct sockaddr *address,
                          socklen_t length, const char *address_str)
 {
-    if (xfer->local_address)
-        free (xfer->local_address);
+    free (xfer->local_address);
     xfer->local_address = malloc (length);
     xfer->local_address_length = length;
     if (xfer->local_address)
 	memcpy (xfer->local_address, address, length);
 
-    if (xfer->local_address_str)
-        free (xfer->local_address_str);
+    free (xfer->local_address_str);
     xfer->local_address_str = strdup ((address_str) ? address_str : "");
 }
 
@@ -932,49 +938,30 @@ xfer_free (struct t_xfer *xfer)
         (xfer->next_xfer)->prev_xfer = xfer->prev_xfer;
 
     /* free data */
-    if (xfer->plugin_id)
-        free (xfer->plugin_id);
-    if (xfer->plugin_name)
-        free (xfer->plugin_name);
-    if (xfer->remote_nick)
-        free (xfer->remote_nick);
-    if (xfer->local_nick)
-        free (xfer->local_nick);
-    if (xfer->charset_modifier)
-        free (xfer->charset_modifier);
-    if (xfer->filename)
-        free (xfer->filename);
-    if (xfer->proxy)
-        free (xfer->proxy);
-    if (xfer->local_address)
-        free (xfer->local_address);
-    if (xfer->local_address_str)
-        free (xfer->local_address_str);
-    if (xfer->remote_address)
-        free (xfer->remote_address);
-    if (xfer->remote_address_str)
-        free (xfer->remote_address_str);
-    if (xfer->remote_nick_color)
-        free (xfer->remote_nick_color);
-    if (xfer->hook_fd)
-        weechat_unhook (xfer->hook_fd);
-    if (xfer->hook_timer)
-        weechat_unhook (xfer->hook_timer);
-    if (xfer->hook_connect)
-        weechat_unhook (xfer->hook_connect);
-    if (xfer->unterminated_message)
-        free (xfer->unterminated_message);
-    if (xfer->local_filename)
-        free (xfer->local_filename);
-    if (xfer->temp_local_filename)
-        free (xfer->temp_local_filename);
+    free (xfer->plugin_id);
+    free (xfer->plugin_name);
+    free (xfer->remote_nick);
+    free (xfer->local_nick);
+    free (xfer->charset_modifier);
+    free (xfer->filename);
+    free (xfer->proxy);
+    free (xfer->local_address);
+    free (xfer->local_address_str);
+    free (xfer->remote_address);
+    free (xfer->remote_address_str);
+    free (xfer->remote_nick_color);
+    weechat_unhook (xfer->hook_fd);
+    weechat_unhook (xfer->hook_timer);
+    weechat_unhook (xfer->hook_connect);
+    free (xfer->unterminated_message);
+    free (xfer->local_filename);
+    free (xfer->temp_local_filename);
     if (xfer->hash_handle)
     {
         gcry_md_close (*xfer->hash_handle);
         free (xfer->hash_handle);
     }
-    if (xfer->hash_target)
-        free (xfer->hash_target);
+    free (xfer->hash_target);
 
     free (xfer);
 
@@ -1064,6 +1051,9 @@ xfer_add_cb (const void *pointer, void *data,
     token = weechat_infolist_string (infolist, "token");
     protocol = XFER_NO_PROTOCOL;
 
+    memset (&local_addr_storage, 0, sizeof (local_addr_storage));
+    local_addr_length = sizeof (local_addr_storage);
+
     if (!plugin_name || !plugin_id || !str_type || !remote_nick || !local_nick)
     {
         weechat_printf (NULL,
@@ -1131,8 +1121,7 @@ xfer_add_cb (const void *pointer, void *data,
             path = weechat_string_eval_path_home (
                 weechat_config_string (xfer_config_file_upload_path),
                 NULL, NULL, options);
-            if (options)
-                weechat_hashtable_free (options);
+            weechat_hashtable_free (options);
             if (!path)
             {
                 weechat_printf (NULL,
@@ -1234,8 +1223,6 @@ xfer_add_cb (const void *pointer, void *data,
         {
             /* no own_ip, so bind_addr's family comes from irc connection  */
             /* use the local interface, from the server socket */
-            memset (&local_addr_storage, 0, sizeof (local_addr_storage));
-            local_addr_length = sizeof (local_addr_storage);
             server_sock = weechat_infolist_integer (infolist, "socket");
             if (getsockname (server_sock, (struct sockaddr *)&local_addr_storage, &local_addr_length))
             {
@@ -1330,7 +1317,7 @@ xfer_add_cb (const void *pointer, void *data,
         }
     }
 
-    if (XFER_IS_FILE(type))
+    if (XFER_IS_FILE(type) && filename2)
     {
         /* extract short filename (without path) */
         pos = strrchr (filename2, DIR_SEPARATOR_CHAR);
@@ -1395,18 +1382,14 @@ xfer_add_cb (const void *pointer, void *data,
     if (XFER_IS_SEND(ptr_xfer->type) && !XFER_HAS_ENDED(ptr_xfer->status))
         xfer_send_signal (ptr_xfer, "xfer_send_ready");
 
-    if (filename2)
-        free (filename2);
-    if (short_filename)
-        free (short_filename);
+    free (filename2);
+    free (short_filename);
     weechat_infolist_reset_item_cursor (infolist);
     return WEECHAT_RC_OK_EAT;
 
 error:
-    if (filename2)
-        free (filename2);
-    if (short_filename)
-        free (short_filename);
+    free (filename2);
+    free (short_filename);
     weechat_infolist_reset_item_cursor (infolist);
     return WEECHAT_RC_ERROR;
 }
@@ -1731,65 +1714,65 @@ xfer_print_log ()
     for (ptr_xfer = xfer_list; ptr_xfer; ptr_xfer = ptr_xfer->next_xfer)
     {
         weechat_log_printf ("");
-        weechat_log_printf ("[xfer (addr:0x%lx)]", ptr_xfer);
-        weechat_log_printf ("  plugin_name . . . . . . : '%s'",  ptr_xfer->plugin_name);
-        weechat_log_printf ("  plugin_id . . . . . . . : '%s'",  ptr_xfer->plugin_id);
+        weechat_log_printf ("[xfer (addr:%p)]", ptr_xfer);
+        weechat_log_printf ("  plugin_name . . . . . . : '%s'", ptr_xfer->plugin_name);
+        weechat_log_printf ("  plugin_id . . . . . . . : '%s'", ptr_xfer->plugin_id);
         weechat_log_printf ("  type. . . . . . . . . . : %d (%s)",
                             ptr_xfer->type,
                             xfer_type_string[ptr_xfer->type]);
         weechat_log_printf ("  protocol. . . . . . . . : %d (%s)",
                             ptr_xfer->protocol,
                             xfer_protocol_string[ptr_xfer->protocol]);
-        weechat_log_printf ("  remote_nick . . . . . . : '%s'",  ptr_xfer->remote_nick);
-        weechat_log_printf ("  local_nick. . . . . . . : '%s'",  ptr_xfer->local_nick);
-        weechat_log_printf ("  charset_modifier. . . . : '%s'",  ptr_xfer->charset_modifier);
-        weechat_log_printf ("  filename. . . . . . . . : '%s'",  ptr_xfer->filename);
-        weechat_log_printf ("  size. . . . . . . . . . : %llu",  ptr_xfer->size);
-        weechat_log_printf ("  proxy . . . . . . . . . : '%s'",  ptr_xfer->proxy);
-        weechat_log_printf ("  local_address . . . . . : 0x%lx", ptr_xfer->local_address);
-        weechat_log_printf ("  local_address_length. . : %d",    ptr_xfer->local_address_length);
-        weechat_log_printf ("  local_address_str . . . : '%s'" , ptr_xfer->local_address_str);
-        weechat_log_printf ("  remote_address. . . . . : 0x%lx", ptr_xfer->remote_address);
-        weechat_log_printf ("  remote_address_length . : %d",    ptr_xfer->remote_address_length);
-        weechat_log_printf ("  remote_address_str. . . : '%s'",  ptr_xfer->remote_address_str);
-        weechat_log_printf ("  port. . . . . . . . . . : %d",    ptr_xfer->port);
-        weechat_log_printf ("  token . . . . . . . . . : %s",    ptr_xfer->token);
+        weechat_log_printf ("  remote_nick . . . . . . : '%s'", ptr_xfer->remote_nick);
+        weechat_log_printf ("  local_nick. . . . . . . : '%s'", ptr_xfer->local_nick);
+        weechat_log_printf ("  charset_modifier. . . . : '%s'", ptr_xfer->charset_modifier);
+        weechat_log_printf ("  filename. . . . . . . . : '%s'", ptr_xfer->filename);
+        weechat_log_printf ("  size. . . . . . . . . . : %llu", ptr_xfer->size);
+        weechat_log_printf ("  proxy . . . . . . . . . : '%s'", ptr_xfer->proxy);
+        weechat_log_printf ("  local_address . . . . . : %p", ptr_xfer->local_address);
+        weechat_log_printf ("  local_address_length. . : %d", ptr_xfer->local_address_length);
+        weechat_log_printf ("  local_address_str . . . : '%s'", ptr_xfer->local_address_str);
+        weechat_log_printf ("  remote_address. . . . . : %p", ptr_xfer->remote_address);
+        weechat_log_printf ("  remote_address_length . : %d", ptr_xfer->remote_address_length);
+        weechat_log_printf ("  remote_address_str. . . : '%s'", ptr_xfer->remote_address_str);
+        weechat_log_printf ("  port. . . . . . . . . . : %d", ptr_xfer->port);
+        weechat_log_printf ("  token . . . . . . . . . : %s", ptr_xfer->token);
 
         weechat_log_printf ("  status. . . . . . . . . : %d (%s)",
                             ptr_xfer->status,
                             xfer_status_string[ptr_xfer->status]);
-        weechat_log_printf ("  buffer. . . . . . . . . : 0x%lx", ptr_xfer->buffer);
-        weechat_log_printf ("  remote_nick_color . . . : '%s'",  ptr_xfer->remote_nick_color);
-        weechat_log_printf ("  fast_send . . . . . . . : %d",    ptr_xfer->fast_send);
-        weechat_log_printf ("  blocksize . . . . . . . : %d",    ptr_xfer->blocksize);
-        weechat_log_printf ("  start_time. . . . . . . : %lld",  (long long)ptr_xfer->start_time);
-        weechat_log_printf ("  start_transfer. . . . . : %lld",  (long long)ptr_xfer->start_transfer);
-        weechat_log_printf ("  sock. . . . . . . . . . : %d",    ptr_xfer->sock);
-        weechat_log_printf ("  child_pid . . . . . . . : %d",    ptr_xfer->child_pid);
-        weechat_log_printf ("  child_read. . . . . . . : %d",    ptr_xfer->child_read);
-        weechat_log_printf ("  child_write . . . . . . : %d",    ptr_xfer->child_write);
-        weechat_log_printf ("  hook_fd . . . . . . . . : 0x%lx", ptr_xfer->hook_fd);
-        weechat_log_printf ("  hook_timer. . . . . . . : 0x%lx", ptr_xfer->hook_timer);
-        weechat_log_printf ("  hook_connect. . . . . . : 0x%lx", ptr_xfer->hook_connect);
-        weechat_log_printf ("  unterminated_message. . : '%s'",  ptr_xfer->unterminated_message);
-        weechat_log_printf ("  file. . . . . . . . . . : %d",    ptr_xfer->file);
-        weechat_log_printf ("  local_filename. . . . . : '%s'",  ptr_xfer->local_filename);
-        weechat_log_printf ("  temp_local_filename . . : '%s'",  ptr_xfer->temp_local_filename);
-        weechat_log_printf ("  filename_suffix . . . . : %d",    ptr_xfer->filename_suffix);
-        weechat_log_printf ("  pos . . . . . . . . . . : %llu",  ptr_xfer->pos);
-        weechat_log_printf ("  ack . . . . . . . . . . : %llu",  ptr_xfer->ack);
-        weechat_log_printf ("  start_resume. . . . . . : %llu",  ptr_xfer->start_resume);
-        weechat_log_printf ("  last_check_time . . . . : %lld",  (long long)ptr_xfer->last_check_time);
-        weechat_log_printf ("  last_check_pos. . . . . : %llu",  ptr_xfer->last_check_pos);
-        weechat_log_printf ("  last_activity . . . . . : %lld",  (long long)ptr_xfer->last_activity);
-        weechat_log_printf ("  bytes_per_sec . . . . . : %llu",  ptr_xfer->bytes_per_sec);
-        weechat_log_printf ("  eta . . . . . . . . . . : %llu",  ptr_xfer->eta);
-        weechat_log_printf ("  hash_target . . . . . . : '%s'",  ptr_xfer->hash_target);
+        weechat_log_printf ("  buffer. . . . . . . . . : %p", ptr_xfer->buffer);
+        weechat_log_printf ("  remote_nick_color . . . : '%s'", ptr_xfer->remote_nick_color);
+        weechat_log_printf ("  fast_send . . . . . . . : %d", ptr_xfer->fast_send);
+        weechat_log_printf ("  blocksize . . . . . . . : %d", ptr_xfer->blocksize);
+        weechat_log_printf ("  start_time. . . . . . . : %lld", (long long)ptr_xfer->start_time);
+        weechat_log_printf ("  start_transfer. . . . . : %lld", (long long)ptr_xfer->start_transfer);
+        weechat_log_printf ("  sock. . . . . . . . . . : %d", ptr_xfer->sock);
+        weechat_log_printf ("  child_pid . . . . . . . : %d", ptr_xfer->child_pid);
+        weechat_log_printf ("  child_read. . . . . . . : %d", ptr_xfer->child_read);
+        weechat_log_printf ("  child_write . . . . . . : %d", ptr_xfer->child_write);
+        weechat_log_printf ("  hook_fd . . . . . . . . : %p", ptr_xfer->hook_fd);
+        weechat_log_printf ("  hook_timer. . . . . . . : %p", ptr_xfer->hook_timer);
+        weechat_log_printf ("  hook_connect. . . . . . : %p", ptr_xfer->hook_connect);
+        weechat_log_printf ("  unterminated_message. . : '%s'", ptr_xfer->unterminated_message);
+        weechat_log_printf ("  file. . . . . . . . . . : %d", ptr_xfer->file);
+        weechat_log_printf ("  local_filename. . . . . : '%s'", ptr_xfer->local_filename);
+        weechat_log_printf ("  temp_local_filename . . : '%s'", ptr_xfer->temp_local_filename);
+        weechat_log_printf ("  filename_suffix . . . . : %d", ptr_xfer->filename_suffix);
+        weechat_log_printf ("  pos . . . . . . . . . . : %llu", ptr_xfer->pos);
+        weechat_log_printf ("  ack . . . . . . . . . . : %llu", ptr_xfer->ack);
+        weechat_log_printf ("  start_resume. . . . . . : %llu", ptr_xfer->start_resume);
+        weechat_log_printf ("  last_check_time . . . . : %lld", (long long)ptr_xfer->last_check_time);
+        weechat_log_printf ("  last_check_pos. . . . . : %llu", ptr_xfer->last_check_pos);
+        weechat_log_printf ("  last_activity . . . . . : %lld", (long long)ptr_xfer->last_activity);
+        weechat_log_printf ("  bytes_per_sec . . . . . : %llu", ptr_xfer->bytes_per_sec);
+        weechat_log_printf ("  eta . . . . . . . . . . : %llu", ptr_xfer->eta);
+        weechat_log_printf ("  hash_target . . . . . . : '%s'", ptr_xfer->hash_target);
         weechat_log_printf ("  hash_status . . . . . . : %d (%s)",
                             ptr_xfer->hash_status,
                             xfer_hash_status_string[ptr_xfer->hash_status]);
-        weechat_log_printf ("  prev_xfer . . . . . . . : 0x%lx", ptr_xfer->prev_xfer);
-        weechat_log_printf ("  next_xfer . . . . . . . : 0x%lx", ptr_xfer->next_xfer);
+        weechat_log_printf ("  prev_xfer . . . . . . . : %p", ptr_xfer->prev_xfer);
+        weechat_log_printf ("  next_xfer . . . . . . . : %p", ptr_xfer->next_xfer);
     }
 }
 
@@ -1879,16 +1862,21 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
     /* make C compiler happy */
     (void) plugin;
 
-    xfer_config_write ();
+    if (xfer_buffer)
+    {
+        weechat_buffer_close (xfer_buffer);
+        xfer_buffer = NULL;
+    }
+    xfer_buffer_selected_line = 0;
 
-    if (xfer_signal_upgrade_received)
-        xfer_upgrade_save ();
+    xfer_config_write ();
 
     xfer_disconnect_all ();
 
     xfer_free_all ();
 
     weechat_config_free (xfer_config_file);
+    xfer_config_file = NULL;
 
     return WEECHAT_RC_OK;
 }
