@@ -1,7 +1,7 @@
 /*
  * test-gui-bar-item.cpp - test bar item functions
  *
- * Copyright (C) 2022-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2022-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -188,7 +188,8 @@ TEST(GuiBarItem, Update)
 
 TEST(GuiBarItem, Free)
 {
-    /* TODO: write tests */
+    /* test free of NULL bar item */
+    gui_bar_item_free (NULL);
 }
 
 /*
