@@ -161,7 +161,7 @@ TEST(GuiBuffer, GetPluginName)
                              NULL, NULL, NULL);
     CHECK(buffer);
 
-    POINTERS_EQUAL(NULL, gui_buffer_get_plugin_name (NULL));
+    STRCMP_EQUAL(NULL, gui_buffer_get_plugin_name (NULL));
 
     STRCMP_EQUAL("core", gui_buffer_get_plugin_name (buffer));
 
@@ -271,8 +271,8 @@ TEST(GuiBuffer, LocalVarAddRemove)
     gui_buffer_local_var_remove_all (NULL);
 
     gui_buffer_local_var_remove_all (buffer);
-    POINTERS_EQUAL(NULL,
-                   hashtable_get_string (buffer->local_variables, "keys_values"));
+    STRCMP_EQUAL(NULL,
+                 hashtable_get_string (buffer->local_variables, "keys_values"));
 
     gui_buffer_close (buffer);
 }
@@ -468,7 +468,6 @@ TEST(GuiBuffer, ApplyConfigProperties)
  * Test callback for buffer input.
  */
 
-
 int
 test_buffer_input_cb (const void *pointer, void *data,
                       struct t_gui_buffer *buffer, const char *input_data)
@@ -520,13 +519,13 @@ TEST(GuiBuffer, NewProps)
                                    &test_buffer_close_cb, NULL, NULL);
     CHECK(buffer);
     POINTERS_EQUAL(NULL, buffer->plugin);
-    POINTERS_EQUAL(NULL, buffer->plugin_name_for_upgrade);
+    STRCMP_EQUAL(NULL, buffer->plugin_name_for_upgrade);
     LONGS_EQUAL(2, buffer->number);
     LONGS_EQUAL(0, buffer->layout_number);
     LONGS_EQUAL(0, buffer->layout_number_merge_order);
     STRCMP_EQUAL(TEST_BUFFER_NAME, buffer->name);
     STRCMP_EQUAL("core." TEST_BUFFER_NAME, buffer->full_name);
-    POINTERS_EQUAL(NULL, buffer->old_full_name);
+    STRCMP_EQUAL(NULL, buffer->old_full_name);
     STRCMP_EQUAL(TEST_BUFFER_NAME, buffer->short_name);
     LONGS_EQUAL(GUI_BUFFER_TYPE_FREE, buffer->type);
     LONGS_EQUAL(GUI_BUFFER_NOTIFY_ALL, buffer->notify);
@@ -542,8 +541,8 @@ TEST(GuiBuffer, NewProps)
     POINTERS_EQUAL(NULL, buffer->close_callback_pointer);
     POINTERS_EQUAL(NULL, buffer->close_callback_data);
     LONGS_EQUAL(0, buffer->closing);
-    POINTERS_EQUAL(NULL, buffer->title);
-    POINTERS_EQUAL(NULL, buffer->modes);
+    STRCMP_EQUAL(NULL, buffer->title);
+    STRCMP_EQUAL(NULL, buffer->modes);
     CHECK(buffer->own_lines);
     POINTERS_EQUAL(NULL, buffer->own_lines->first_line);
     POINTERS_EQUAL(NULL, buffer->own_lines->last_line);
@@ -573,7 +572,7 @@ TEST(GuiBuffer, NewProps)
     LONGS_EQUAL(0, buffer->input_get_unknown_commands);
     LONGS_EQUAL(0, buffer->input_get_empty);
     LONGS_EQUAL(0, buffer->input_multiline);
-    POINTERS_EQUAL(NULL, buffer->input_prompt);
+    STRCMP_EQUAL(NULL, buffer->input_prompt);
     STRCMP_EQUAL("", buffer->input_buffer);
     CHECK(buffer->input_buffer_alloc > 0);
     LONGS_EQUAL(0, buffer->input_buffer_size);
@@ -581,7 +580,7 @@ TEST(GuiBuffer, NewProps)
     LONGS_EQUAL(0, buffer->input_buffer_pos);
     LONGS_EQUAL(0, buffer->input_buffer_1st_display);
     CHECK(buffer->input_undo_snap);
-    POINTERS_EQUAL(NULL, buffer->input_undo_snap->data);
+    STRCMP_EQUAL(NULL, buffer->input_undo_snap->data);
     LONGS_EQUAL(0, buffer->input_undo_snap->pos);
     POINTERS_EQUAL(NULL, buffer->input_undo_snap->prev_undo);
     POINTERS_EQUAL(NULL, buffer->input_undo_snap->next_undo);
@@ -603,14 +602,14 @@ TEST(GuiBuffer, NewProps)
     LONGS_EQUAL(0, buffer->text_search_history);
     LONGS_EQUAL(0, buffer->text_search_found);
     POINTERS_EQUAL(NULL, buffer->text_search_ptr_history);
-    POINTERS_EQUAL(NULL, buffer->text_search_input);
-    POINTERS_EQUAL(NULL, buffer->highlight_words);
-    POINTERS_EQUAL(NULL, buffer->highlight_regex);
+    STRCMP_EQUAL(NULL, buffer->text_search_input);
+    STRCMP_EQUAL(NULL, buffer->highlight_words);
+    STRCMP_EQUAL(NULL, buffer->highlight_regex);
     POINTERS_EQUAL(NULL, buffer->highlight_regex_compiled);
-    POINTERS_EQUAL(NULL, buffer->highlight_tags_restrict);
+    STRCMP_EQUAL(NULL, buffer->highlight_tags_restrict);
     LONGS_EQUAL(0, buffer->highlight_tags_restrict_count);
     POINTERS_EQUAL(NULL, buffer->highlight_tags_restrict_array);
-    POINTERS_EQUAL(NULL, buffer->highlight_tags);
+    STRCMP_EQUAL(NULL, buffer->highlight_tags);
     LONGS_EQUAL(0, buffer->highlight_tags_count);
     POINTERS_EQUAL(NULL, buffer->highlight_tags_array);
     POINTERS_EQUAL(NULL, buffer->hotlist);
@@ -674,13 +673,13 @@ TEST(GuiBuffer, New)
                              &test_buffer_close_cb, NULL, NULL);
     CHECK(buffer);
     POINTERS_EQUAL(NULL, buffer->plugin);
-    POINTERS_EQUAL(NULL, buffer->plugin_name_for_upgrade);
+    STRCMP_EQUAL(NULL, buffer->plugin_name_for_upgrade);
     LONGS_EQUAL(2, buffer->number);
     LONGS_EQUAL(0, buffer->layout_number);
     LONGS_EQUAL(0, buffer->layout_number_merge_order);
     STRCMP_EQUAL(TEST_BUFFER_NAME, buffer->name);
     STRCMP_EQUAL("core." TEST_BUFFER_NAME, buffer->full_name);
-    POINTERS_EQUAL(NULL, buffer->old_full_name);
+    STRCMP_EQUAL(NULL, buffer->old_full_name);
     STRCMP_EQUAL(TEST_BUFFER_NAME, buffer->short_name);
     gui_buffer_close (buffer);
 }
@@ -916,27 +915,27 @@ TEST(GuiBuffer, GetInteger)
 
 TEST(GuiBuffer, GetString)
 {
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, NULL));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, ""));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "zzz"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, NULL));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, ""));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "zzz"));
 
     STRCMP_EQUAL("core", gui_buffer_get_string (gui_buffers, "plugin"));
     STRCMP_EQUAL("weechat", gui_buffer_get_string (gui_buffers, "name"));
     STRCMP_EQUAL("core.weechat", gui_buffer_get_string (gui_buffers, "full_name"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "old_full_name"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "old_full_name"));
     STRCMP_EQUAL("weechat", gui_buffer_get_string (gui_buffers, "short_name"));
     STRCMP_EQUAL("formatted", gui_buffer_get_string (gui_buffers, "type"));
     STRNCMP_EQUAL("WeeChat ", gui_buffer_get_string (gui_buffers, "title"), 8);
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "modes"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "input_prompt"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "modes"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "input_prompt"));
     STRCMP_EQUAL("", gui_buffer_get_string (gui_buffers, "input"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "text_search_input"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_words"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_disable_regex"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_regex"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_tags_restrict"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_tags"));
-    POINTERS_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "hotlist_max_level_nicks"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "text_search_input"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_words"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_disable_regex"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_regex"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_tags_restrict"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "highlight_tags"));
+    STRCMP_EQUAL(NULL, gui_buffer_get_string (gui_buffers, "hotlist_max_level_nicks"));
 }
 
 /*
@@ -1094,10 +1093,10 @@ TEST(GuiBuffer, SetHighlightWords)
     gui_buffer_set_highlight_words (NULL, NULL);
 
     gui_buffer_set_highlight_words (buffer, NULL);
-    POINTERS_EQUAL(NULL, buffer->highlight_words);
+    STRCMP_EQUAL(NULL, buffer->highlight_words);
 
     gui_buffer_set_highlight_words (buffer, "");
-    POINTERS_EQUAL(NULL, buffer->highlight_words);
+    STRCMP_EQUAL(NULL, buffer->highlight_words);
 
     gui_buffer_set_highlight_words (buffer, "test");
     STRCMP_EQUAL("test", buffer->highlight_words);
@@ -1121,12 +1120,12 @@ TEST(GuiBuffer, SetHighlightWordsList)
     CHECK(buffer);
 
     gui_buffer_set_highlight_words_list (buffer, NULL);
-    POINTERS_EQUAL(NULL, buffer->highlight_words);
+    STRCMP_EQUAL(NULL, buffer->highlight_words);
 
     list = weelist_new ();
 
     gui_buffer_set_highlight_words_list (buffer, list);
-    POINTERS_EQUAL(NULL, buffer->highlight_words);
+    STRCMP_EQUAL(NULL, buffer->highlight_words);
 
     /* add "word1" */
     weelist_add (list, "word1", WEECHAT_LIST_POS_END, NULL);
@@ -1230,13 +1229,13 @@ TEST(GuiBuffer, RemoveHotlistMaxLevelNicks)
 
 TEST(GuiBuffer, SetInputPrompt)
 {
-    POINTERS_EQUAL(NULL, gui_buffers->input_prompt);
+    STRCMP_EQUAL(NULL, gui_buffers->input_prompt);
 
     gui_buffer_set_input_prompt (gui_buffers, "test");
     STRCMP_EQUAL("test", gui_buffers->input_prompt);
 
     gui_buffer_set_input_prompt (gui_buffers, "");
-    POINTERS_EQUAL(NULL, gui_buffers->input_prompt);
+    STRCMP_EQUAL(NULL, gui_buffers->input_prompt);
 }
 
 /*
