@@ -1,7 +1,7 @@
 /*
  * test-irc-batch.cpp - test IRC batch functions
  *
- * Copyright (C) 2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2023-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -26,7 +26,7 @@
 extern "C"
 {
 #include <string.h>
-#include "src/core/wee-hashtable.h"
+#include "src/core/core-hashtable.h"
 #include "src/plugins/weechat-plugin.h"
 #include "src/plugins/irc/irc-batch.h"
 #include "src/plugins/irc/irc-server.h"
@@ -135,9 +135,9 @@ TEST(IrcBatch, StartBatch)
     CHECK(batch);
     POINTERS_EQUAL(batch, server->batches);
     STRCMP_EQUAL("ref", batch->reference);
-    POINTERS_EQUAL(NULL, batch->parent_ref);
+    STRCMP_EQUAL(NULL, batch->parent_ref);
     STRCMP_EQUAL("type", batch->type);
-    POINTERS_EQUAL(NULL, batch->parameters);
+    STRCMP_EQUAL(NULL, batch->parameters);
     POINTERS_EQUAL(NULL, batch->tags);
     CHECK(batch->start_time > 0);
     POINTERS_EQUAL(NULL, batch->messages);
